#!/usr/bin/env python
"""
PySimpleBarcode - Licensed under GPL3
Copyright 2022 Andrew Spangler
A basic Code 39 barcode generator using PIL and the Libre Barcode 39 font family
Libre Barcode 39 is subject to the Open Font License and can be found at https://fonts.google.com/specimen/Libre+Barcode+39
Libre Barcode 39 Extended Text is subject to the Open Font License and can be found at https://fonts.google.com/specimen/Libre+Barcode+39+Extended+Text
See OFL.txt for font license details.
"""
__author__ = "Andrew Spangler"
__copyright__ = "Copyright 2022, Andrew Spangler"
__credits__ = [
    "Andrew Spangler (code39.py/PySimpleBarcode), Lasse Fister (Libre Barcode 39)"
]
__license__ = "GPL"
__version__ = "0.1.0"
__maintainer__ = "Andrew Spangler"
__url__ = "https://github.com/AndrewSpangler/PySimpleBarcode"
__requirements__ = ["pillow"]

import io, json, zipfile
from PIL import Image, ImageDraw, ImageFont

BACKGROUND = (255, 255, 255, 255)  # RGBA barcode background
FOREGROUND = (0, 0, 0, 255)  # RGBA barcode foreground
DEFAULT_CL_BG = "#FFFFFFFF"  # RGBA Hexadecimal command line default background
DEFAULT_CL_FG = "#000000FF"  # RGBA Hexadecimal command line default foreground
DEFAULT_PAD = 10  # Default barcode x and y padding
DEFAULT_SIZE = 50  # Default font size to uses
DEFAULT_TYPE = ".png"  # Default image extension to use
FONT_DATA = b"PK\x03\x04\x14\x00\x00\x00\x08\x00\x00\x00\xffJX\xad\x84\xf5\x17\x10\x00\x00\xec9\x00\x00\x08\x00\x00\x00font.ttf\xedYYL+U\x18>\xfft\xa1\xc0L\xd9\x11\xad\xe2\xd4\x11\x17\x18\x10\xd9DE\xc5i\x0b*.\\\xee\xbd\xda\xd6\xad\xa5\x94\x0b\x8aP\xa1Wq\xdf\xb7\xba\xc4\xf8d41\xc6\xb8\xc5\xa7S\xdc\x8d\x0f\xc6\xf8`|0\xc6\xe8\x8b\xbe\x18\x8d\xc6\x18c\xd4\xe8\x8b\x1b~\xe7\xcc\xa9\xc2\xb8EcL5\xb6w\xfa}\xff\x7f\xfes\xfe\xed\xcc\xe9\xf4\xc2\x881\xd6\xc0\xaee>V\x98\xdc\xb9\xdby\xfc\x98\xe7\x8f`\x8c\x9e\x836~\xc6\xce#\x06fJ_\x1c\x04\xf9;\xc8\x99\xdcE\xd9\xc2\xa1\xf7\x1c\xfa!c>?\xe4\x17s\x97\x14\xcd\xfa\x1fj\xf6\xc3\xf8\xb5\x90G\xe7\x0b{.\x9a\xed\xfb\xf6\n,\xb8?ca}Ov\xad\x00}#.1?\xb4g\xe9\xb2\xf9R\xfe\xa1\xab\x18;\xe00\xc6\xf6\x7fe!\x9f\x9d\xeb\xf8`\xfe\x15\xcc?\t\xe3#\x0bP\xf8\xf7g\xdfB>\x18\xf2\xc1\x0b\x17\x15\xd7\xdf-\xb2\x01\xc6\xfcOA\xf7\xfe\xd2J.[|\xff\xca>\xf8\x7f\t\xe3_]\x94]/\xd0\xcd\xe1+1&\xe21\x97\xb3\x17\xe5w'\x96\xdef,x/l\x1e,\xac\xac\x15\xe9\xfes\xb1V\xdd(\xd6x\xbf\xb0\x9a/|r\xd2k\x0f0\xa6\x9d\x03\xfb\xc7\x90;mn\xb2\x06Y\x83\xcbX+\x0b\xc8Kc\x9d,\xc1\xee\x84\xee\xcc\xb0.l\xc4\xb8\x96\xfc\xa1\x00?_A\xdbI/C\xb3\xfd\xb5.5D'\x1d\xf2H\xc7c\xe77\x8c}\xcd\x1a|\x1f\x8b\x81w7\x9b>P\xf8\x19c?\x14\xe8e-\t1\x08/\xbf\xfd\xea\xc4;\xcd\x9a\xb5\xd3\xc5\x1b\xbe\xc5'^[\xb9\xf4W\x07;\x9bQ|\xe2\xd4],\xc4\xfcB\xbd\xb9\xe9F\x92\xcb.\x15\xa1\x03\x93\x97_a\x08W\x90M\xca\x9c\x8e`~z\x8f\xeef\x01\xacZ\x92QM\xb9H\xe7\xa1\xe6\x9fo\r\xe8Z\x94s\xab<9\x13\x9ba\xe3(\xb9\xee\xd6EKb\x1d\xb1\xbe\xf8\xb8[FhB\x9az\x8e\xbd:\x93,\x13\xdd\x95\xe2\xf4|\x08\xdes\x852\xabq6\xf6%\xd6-\xc8\x93\xe1\x10\xd5\xb9\xac=(Y\xc8y\xc1\xf7\x12\xa6\xd6\x83\xd7:/\xc0\x89\xe0\xcf\x0b\xf7\xf1\xf2\xc1t\xeb\x8e$\x1f\xbf5)\xe4\xb9x\xf90!?\x17bPH\x83T\xa4|\xa8P\xbd\x10\xba\x16[b\xfc\xd6\xdc\xae\xca\x80x=\xd9\x18\xa4p\xf7s\xb4y\x13\xf7\xdfY\xd6X\xfc\xc9\xc0\\\x90\xc5\xe3\xb2\xb4\xcc\xcd\xb0\x15\x9f$\xd1\xcf\x1e\x07v`\xf7\xfad\x1d\rd\xd4\xc5z\xd8\xd1\xe8\xcc\xe5\xecA\xf6\xb2\xa9\xa3\xd6L\x8d\x1c\xcc\xbaY/;\x91e\xe5H=F\xb4\xcd\xaf\xb0\xb3t\xcc\xadAW\xbe\xd9|{\xf3)U\xa1\x9f_\xbaB\xecN\xccuX\x8c\xc5\xb1\xf3&\xd0\x9f\x93\xd8\xc9\xec\x146\xc5Ne\xa7\xb1\xd3\xd9\x19l\x9a\xed`3l'\xdb\xc5v\xb33\xd9Y,\xc9R\x88c\x9d]\x8a\x99\xdd\xf2]`\xcf\xb0\xef\xc8\xa1[\xe9u\xadUKk\x0fj\x1f\xf9l\xdf\xaa\xef9\xdf\x0f\xfe\xb8\xbf\xe4\x7f#\xd0\x1e8'\xf0P\xe0\xe3`_\xb0\x18|\xa1\x86\xd5L\xd4\xdcQ\xf3f\xa8#t^\xe8\xe1\xd0'\xb5\xfd\xb5\x97\xd4\xbeX\xa7\xd5\x9dTwW\xdd[\xf5\xfb\xd5g\xea\x1f\xad\xffT\x1f\xc0\xfb\x18\xdd\xd1O\xd1g\xf4\xb4>\xab_\xa0\xaf\xea\x97\xeb\xd7\xeb%\xfd\x1e\xfd>\xfd!\xfd\t}C\x7fA\x7fY\x7fM\x7fS\x7fG\x7f_\xffD\xffR\xff\xc6\xd0\x8c:\xa3\xd9\xd8\xcf8\xc8\xe86\x06\x8cc\x0c\xc78\xc5\x981\xd2\xc6\xacq\x81\xb1j\\n\\o\x94\x8c{\x8c\xfb\x8c\x87\x8c'\x8c\r\xe3\x05\xe3e\xe35\xe3M\xe3\x1d\xe3}\xe3\x13\xe3K\xe3\x9b\xb0\x16\xae\x0b7\x87\xf7\x0b\x1f\x14\xee\x0e\x0f\x84\x8f\t;\xe1S\xc23\xe14\xde\xb3\xe2\x8d\xbbp\xa0RBz\xef\xff\xeb\xbftmy\xd5\xb2Uq7\xfak\xc1_\xd1.P\x9c\x98\xa9\x9d\xa2\xb8\xc6\xc2\xda\x98\xcb\xf1\xe9\xd07\x8a\xfbY?\xbd\xa6x\x80M\xd0\x8d\x8a\x07\x99MI\xc5\r:\x88\x8d(\x1e\x06cl\x81\x15\xf1.\xb05v\x0c\xce\xc6#\x809D\xb0\x08M\x11\xbc\x0f\xd7\"[\x02\xae@\xbb\x07\xe3g\xe0N=\x15w\xe4\x02\xf4k8\x03&0\xb2\xcc\x8a`;\xc1\xe6\xc1.eY\xd8\xe6\xa1q-\x96\x809\xc8\xcbl\r\x9fs\xd0\xec\x05\x9f\x03_\x05/b\xa5\xbc\x9c}2\xd65\xb1~A\xd8n[\xf9\xd4m+\xd8\xd0\x9c)f\xcb\xd8V\xa4\xed\x91\xacO^\xa6\x88\xec\x97~\x7f\x8e\x06\xb1]\x82\x0b9\xe1s\x16\x9fb\xe4R\xc8\x88C\x8cJ\xbf'\xb2\x1d\x92\x17Q\x13\xf3/VH\xc4<+\xeb\xe0\xc8z\xe40.r\x1e\xc4Y\xda\x8bS-\x0f\xdb\xbd2\x8a\xd5_\xcd\xa6\x1f\xefav,$\xe1}\x1ev{\x81+\";U\x95\xc3\xd8%\xd2r\x14\xd7 ;|\x8bG\xd3\xe3\xd3\x94^\xcd\xed^\xb7y\x99\xc4X\x0c\xd7\xb1\x7f*\xeem\xd2\x1f\xfa\x8fA*\xb0\xcbd\xed\xf6\xc8\xaa\x9a8\xd1\xfa\x11\xc7QX\x19L\\n\x07\xc5\x9c\xdf]o\x9a\xad\x82_\x00\x9e\x93\xeb\x9c(\xab\xb3 {\xb0&j\xf3\x8b\xae\xedQ=\xde\x8b5\xfb\xe4J\x17I\xed*V.\x88\xaa\n\x9d\xf0\x06\xed\xd2O\x9eg\xb7\xf9=\xbc\xf2\xfc\xb2\xf94b\xfd\xb5\xd7e\xb8\x9f5\xf2\x91\x9f\x02\x14\xa4\x1a\nQ-\xd5Q=\xe9dP\x98\x1a\xa8\x91\x9a\xa8\x99Z\xa8\x95\xda\xa8\x9d\xf6\xa1\x0e\xda\x97\xf6\xa3\x08\xedO\x07P'\x1dH&E\xe9 \xb2\xe8`\xea\xa2C\xe8P:\x8c\x0e\xa7n\xea!\x9bz\xa9\x8f\x8e\xa0~:\x92\x06h\x90\x86h\x98F\xe8(\x1a\xa5\xa3\xe9\x18:\x96\xc6\xe88:\x9eN\xa0q:\x11\xdf\x861\x8aS\x82&h\x92N\xa2\x93\xe9\x14\x9a\xa2S\xe94:\x9d\xce\xa0i\xdaA3\xb4\x93v\xd1n:\x93\xce\xa2$\xa5(Mg\xd39t.\x9dG\xe7S\x86\xb24K9\x9a\xa3<\xcd\xd3\x1eZ\xa0E\xba\x80.\xa4%\xba\x88\x96i\x85\nt1\xad\xd2\x1a\x15i/]B\x97\xd2:]\xa6\xc5f\xfc\xa7\xef>\xf5\xd4`ne.\xdfw\xa2\x0b\x8e\x0b1\x17\xe2.$\\\x98pa\xd2\x85\x93\\8\xd9\x85S\\\x98rA\xady\x9a\x0b\xa7\xbbp\x86\x0b\xd3.\xecpa\xc6\x85\x9d.\xecra\xb7\x0bg\xbap\x96\x0bI\x17R.\xa4\xeb%\xcc\xad,-eW\xeb$\xcf/\xeeY(\xd6J:\xbfxI^\xb1\x95\xbdj\xf8\xa2\xc5\xe5\xbdk\xaeryq9\x1f\x92le9\xafKR\xc8\xaf\xe6\xf2\xcb\xc5\xfa\x8a\xb0\xb82W\xeb\xf2\xa5\xbdk\xee\x02k\xf9K\xf2\xcb!\x97.\xae+\xddRvmA\xd1B6\x97\x0f\xbb\xb4\x98]-\xae\x15W\n\xeeHqa5\xaf\xfc\x15/]q\x97\xbd<\xbf\xbaR\xb3wy\xb1\xbf\x7f\xa0_\xe1\x90\xc2a\x85'*t\x14\xc6\x15&\x14N\xb88\xd8\xaf\xf0H\x85\x03\n\x07\x15\x0e)\x1cV8\xa2\xf0(\x85\xa3\n\x8fvq\xe8H\x85\x03\n\x07\x15\x0e)\x1cV8\xa2\xf0(\x85\xa3\n+\xeb\x9c\xa8\xd0Q\x18S\x18W\x98P\xa8\xf2\x18\xeeWx\xa4\xc2\x01\x85\x83\n\x87\x14\x0e+\x1cQx\x94\xc2Q\x85G+T\xfeG\x8eT8\xa0pP\xe1\x90\xc2a\x85#\n\x8fR8\xaa\xf0h\x85\x95\xf5\x1c\x851\x85q\x85\t\x85*\x9f\xa3\xfa\x15\x1e\xa9p@\xe1\xa0\xc2!\x85\xc3\nG\x14\x1e\xa5pT\xe1\xd1\n\x95\xff\x13\xd5\xba\xb1\x01\xff\xe5\x97._Ps\xf9\xa5r\xe71\xc6\x99mr\xb6;\x99H\x99&~\xca\x84wL\xf1\xe0\xcet\x92\x0fE\xf8a\xa9\xcc\xbcY\xda\x9d\xe4ZW\xd6\xfda\x93\xb3f#\xd1(g)\xcebV|\x03\xcf)\xb1\x8c\xd3\xcb\xc9\xe6ff\xbe\x97k\xb6\x15\xb5\xa2\xbd\xdcg\x9bsO\xfaZ\xdb\x98\x13\xe3-13\x93q\xcaZk\xcc)w\xf9b\\\x8b\xedZ7\xb9n\x81\xc4\xb2s\xdc?\xbd\xbe\xa1i\x1a\x96\xe1\xd1\xfc\xfeQ\xa1\xdd\x08\xb7\x91\xb3\xbf\tj9\x1b-\xd4\x821\x8b\xb3\xe9d>\xb5\xd1N\x9at\xe8\xb7\xb9\xaf\x87\xb7\xc5\x92\xc2\x1fo\x8f\xc5\x94A\xc4\x9c3\xf9K\xd3\xdc\x7fHz\xe302b\x89\\\x82\x07\x13\xc9(\xf7u\xa5f\xceN\xc28RJ\x9a|z\x1a\xaaqX\xf3Q\xc1FS)\xb3\xecZ#\xa2\xc3\xa0R\x92\xc9\xfb\xc5x?,\xb1j\xd2D5JY\x93\xd7M'3\xd0\x98b\xacN\xb0\x11\xc1F2\x91\x0c~\x80EP-\xae\xc7r\x9c\xcd$9\x9b\x12\xc6Q\xc8\x91)\xde)X\xe7T\xf6\xb9F\x96\x13\x16\xcf\x05\xd8l*5\x97\xc5\xcf\xc6\x9eT\xca\xcd\x00\x91\xcc\xf1v$\x9e\xea\xe5\x01\xdbD\x04\xfe\xae,r\xaa\x89M'y\x8d\xe5\xf0\x90\xe5\xa0\x03\x98\x92\xe9\xe5AYnT\xc2\x9c+\xd7\xcc:\xa6\x18\x14\xe9F\xdc\xf0\xc5'\xec\x129\x1e\xe8\x8eb0f\x96\xcc\x12|\x95\xfb\x03]\xa8\xd0\x8edf:\x92\x9dI%\xadT4e\xf2\xf1\x9dI\x8cEP\x17\x15\n\"\xa8\xb1ym\xacg\x83in\x9bC\x10-\xc7\xc2v\xb1\x9c,\xd7f\xe79\xe5\xe0\x80\xd7t\xf7\xf2Z\xdb\x14\xd1\x86\x91\x96\x9f\xcd\xc2\x04\xf1\x8egR\xc2$\x13\x97\xd1\xd6\xd9\x1b\xb5a\x16K8\xdd\xd1\x9f6N\xbd\xbd}#\xe9r\x15\xc4aA\x8f\xd43f\xa2de\xcd9Ul\x16\x11\r\xe1f\x04AV\xa2Dk\xadl\xdcua\xfc\xc6t~0f1\xcc\xfa\xb5Ia[&\xf4\xa4\xa13_\x02^\"V4\xd5\x8dM\xdc`\x975-\xc1\xe7\xb2\xf1^\xdeh\xc3\xd44yC\xec\x14\xb1\x00\x08:\xc4\x1b\x854\x03\xa9Q\xf6\xab\xc9\x06\x93E1Q\x83\x1c<\xf3\xa6X\xc6,eL\xde\x84\xb2\xf5\xf2f{jW\xb2\xec\x9f\x8b\xa7\x0e\xe6F\xdeZ\xef\xe5-\xf6\xd4\x8e\xe4\xd4NW\x19\x89B\xdf\"\xf5\xadv\x995\xc7v'\xcb\xcd\xcdha\xd6\xe1M=\xe2\x96\xc3\xd6r\xca\r\xe2\xa3\x11\x1f\x9c\xda-\x13\x99L'\xcb\xa2|\xc8\xd7)\x95L\xe1\xb6\xb1;jaZ\x85G\xe4\xb8\x98\x8cKjR\xc8d\x12\xf1OB\xbb\xbdY\xbf\xd1\xc22c-\x16\xea\x15\xe3\xec\xf8\r\"\x92\xddj\xb3Y\x99i\x89]I\xdel9f\x82\x87\xb1\xfd\x0c8\xce8f\xe6\xd9\x8e\x0ebM\xac\x859\x8e#*\xd0\x8a1\xca\x96[C=\xfc\xf6\x9e\xc8A(W;rl\xeb\xe9\xe5\xfb\xd8e\x12\xd8\x81z\x0b\xdc\xd7.\xfb\x04\xeeg\x97\xfd\x02#v9 p\x7f\xbb\x1c\x14x\x80]\xae\x11\xd8i\x97C\x02\x0f\xb4\xcb\xb5\x02{l\xabR\x7f\x1e\xcc\xa0\xd2\x96\xd9\xc7\xe9\\\xdc-pfo\x19l\xffi\xf0bw\xb0w\xcb\xe0!?\r\xae\xba\x83\xa6\xcdxC\xcfo\xe6\x89\xa4\x9evS\x15yn\xcd/\x8a\xfcL\xc4u\x10\xf2\x13h!?\x81\x07#?\x81]\xc8O\xe0!\xc8O\xe0\xa1\xc8O\xe0a\xc8O\xe0\xe1\xc8O`7\xf2\x13\xd8g\x9bcr\xc3\x1ea\xc3mG\xc6\x8c\x89\x10b\xa2\xa5\xe2&\xec\x13{\xb6\xdf\xe6G\xf4\xf0#p?\x1e\x89[a\xd2\xfc\x8dnZ\xd9QK\x1c\xec\xbfk\x11\x11\xd9\x0fTZ\\\x0e\x07\x13b\xc7\xf1#\xbb\xcb\x01jK$\xfbS2\xcbAY\x9e\xdf\xb7\x19\xb2\xcda\x19\xf90Vsm\x12\xbf\xf4\x89\xdbV\xc5\xf2K=k\x7f\x8a\x89W\xfcxk\xb4<Dm\"\xd7\x11\xd4\xc3\x9c\xfc\x8d\xf8q\xb3dG{\xf9Qv\xdf>c\xbd|\xf4\x8fL\xb1\xb1s0?\x1a-b\xed]f\x9f9)\x8e\x04\x94\xf6\xe4Ri\xd2\x9a\xc4\x19\x92\x9c\x8d\x88S\x17\xdfH\xa3Dm\xad\xa8\xf016\xc2\xe2\xfb\xc0\xcc\xdf\x85\x7f\xd2\xac\xac3\x87\xd7\xc7z\xf2\xa5>\xcb4\xc7JX\xf3\xd8mfX\xdb]\x8f\x07-\xa7bm\xf2\x8c8S\xc6w$\x9f\xf4\x9b\x013\xf2\xa4\xff\x90\xc0~)G\x9c\xb4u1\xdc\xc4r\x865\x91\xe1At\xdb\x13\xbd8\xed\xdco%\x7f,3g\xf1\x00\xbeT\xa7\x93\x10\xb2\x11\xf0\x8c8\xe9\xbcs\xb2\x08\r\xe7\xbf5\x81\x1e[\xf00\x81<\x01\xd2\x0b\xd6\xfb\x15'\x96<S1\x92\x11\xcd\x08teqy\x8d\xb0\xa2\x08\xa2K\x04\xe1\xc3\xa7:I\x7f\xf6\x85\x8d0V\xa9\x85\tm\xe0\x10U\x0bk\x0ce:\xae2\x84\x9c\xe5\xf8\x845)\x9c\x8a.\x1e_\x19\x93\xc9\xb8\x95\xe6lW\xb2\xcf\x1c\xc3\x17:4\x15%\x16\xfd\xa9\x15<\xd8\x05\xe9\xe4\xad\xcf.n\x13\x7fm\xb7\xabnYb\xcb\x9f\xb0%\x92X\xa5]\x19\xf1\x80\xe3M\xb9\xd2\xe2q\x1b\x07\x86\xa8\xe2\x04\xdf'\x96\x9c\x8e\xe0;\xd5\x1cK\xf5\x95\xfb\xa9\x15\xf7\xed\x89\xdbFg\"\xd3\xdbF\x9d_\x9d\xfb{3b6?\xa6\xe7\xf7\x1c\xc6m~lO\t\xb1\x89=V\x1a\xfdmS4\xb4\x8f\xf7cFB\xa4,\xf7\xe7!n\xe5\xb3x@s\xdc\xd4\xc5\x06\xb5p\xfb\xf4Y\xa3j\xfd\t\xbb\\\x87\xef\x1aL\xf9+[z\xf2\xef\xda\xc5\"'q\x8e\x8dY8\xaa\xb6\xec\x97hJ\xc59\x89\x03\xf8\x98\x9eJUN\x82tlO\xd4Ruq\xb3\xf9\xb9\x04'\xa3\x04m\xeem\xbf\xc1\xc4\x1d\xde\xd2\xc7Gp\x97\x9f\xf2\x1b\xfa),G\xad-\xfc(\xf0Sm~4\xe04Q\xc5\x04\xcamN\xe0\x8b\xb7R\xad\xd3m\xb1\xa1\xf9i\xa0g\xd8\x1b\x8cM\x80L\x83\x90 ;\xec\r\x92\x9a\x19\x10\xa9\xd9)l&Av\t\x1bAvcHj\xce\x04\x91\x9a\xb3\xec'q\x16\xc6\xc0\x92`$Y\xca~\x92\\]\x1a\xcc\xd5\x9d-\xecH\xb0s\x84\x9dd\xe7b\xd4\xd5\x9d\x07\xe6\xea\xce\x17>\x13 \x19\xe1S\x90\xac\xf0)\xc8,\x88\xd4\xe4\x84\xcdI s\xc2F\x90<\x86\xa4f\x1eDj\xf6\xc8\xb8\xe2`\x0b\xc2\x9fd\x8b\xc2\x9fd\x17\x80\xb9\xba\x0be\\\x82-\t;\xc9.\xc2\xa8\xab[\x06su+\xa8\xf1\xd8O\r,H\x89\x8f\x83^\xec\xd2\x13AWE\xd1\xa5\xe4@Z\xc3w\xad\xb2)\x82*\x9b\xbd\xd2\x86\x94\xcd%\x98|\xdcO\xab^*$w\xc6\xba\xa0\xee\x8c\xcb\x04u\xcd/\xc7:\xca\xe0\nPep%\xa82\xb8\n\xb6\xc7\xff\xb4\xde\xd5Br\xcd\xaf\x11\xd45\xbfVP\xd7\xfc:\xccT\x06\xd7\x83*\x83\x1b@\x95\xc1\x8d\xb0=\xe1\xa7\xf5n\x12\x92k~\xb3\xa0\xae\xf9-\x82\xba\xe6\xb7b\xa62\xb8\rT\x19\x94@\x95\xc1\xed\xf6F\xbd|\xb2\xe5\xc1\xc8\x86_\xf3%\xf0\xa3\t\xc7`\xca\xe9\xe1\xa1<\xf7\x1d<\xbd^\xf9\xb2\xee\xc5\x83\xfe\x80\xfa\xeb\x9d\x0f\x7f\xd1\xe9\x1e?T\xfc\xc5Hc\xbe=L#\xd2\xceb\x9aF\xe7\xfb\xc1\xe8\x0c\xc6j\x82\x01?\xcc|M\x81\xe0>=-M\xd1\xa6\xaehSt\x80\xee\xfe\xe1!\xb2\x7fx\xeb\x87\x82\xef\xe3\xef:\x06|7\xe2\xff\xa6\xf1\xc2\x9a\xa7\xcb5\xebY\x03\x1e\n\x13\xe3N(\xe8\xd7\xfc\xf8\xbb\xe9i\xe1Z\xa3F\x0f\xd4\xfb\xeaj\t\xff[vzc\xa3\xae\x87B~1\xd4\xd2\xd8\xd2\xdc\xa47\xe8\ra#T\x1f\xaa\xaf\xab\xf5\xd7\xf8\xe1U:m\xa8\xd9\xa7\xe7\xc8\xa6\xc1_\xbc\xd3\x9dx\xa5\xf1O;\xfd\xfb\r\xef\xf5\x0f\xc7\x82(\xaa&\x96\xb4\x8a\xa5\xb3\nb\x91-\xaa\x9a\xba \x8e\xaa\xa9K\xba\x8ab\x91\x85\xa9\x9a\x1e!\x96*\xa9K\xba\x8abA(U\x12\x0b\xa2\x90\xe1T\xc3~A\x18U\x13KZ\xc5R\r=\x92\x81TM]\x10H\xd5\xd4%]E\xb1\xc8.UM\x8f\x10K\x95\xd4%]E\xb1 \x92*\x89%-\x9bT\x1d\xcfR(I\xd5\xc4\x92\x96\xb1T\xc9\xb3\x948\\\xaa\xa6.\x88\xa3j\xea\x92\xae\xa2X:\xd3\xd5\xf2\xfb\xc8mQ\xd5<\xd7\xa5\xab\xa6G\x88\xa5Z\xee#w\xe3V\xc7\xef#\xc4QU\xfb\xa5Z\xbe\x03\xdc\x06U\xc7s\x9d\xe8P\xb5\xf4H\x84Q-u\x11\x91T\xd3}T5g\x1dJR5\xbf\x1b\xd3\xe9\xaa\xda\xbb\xe9*\x89E\xfc\x06\xa8\x9ag\xcc\xcetU\x9d\xbb\xbf\xd9\xa3\xcd\xcdJ,Z\x90\x1d\xc0\xd86\xf9`\x8f\xdc\xe3\x91\x0f\xf1\xc8Q\x8f\xdc\xe5\x91\x0f\xf7\xc8}\x1e\xd9\xf2\xc8\xbd\x1e\xd9\xf6\xc8\xa6G>\xd0#\x1f\xe6\x91\x0f\xf5\xc8\x9d\x1e\xf9 \x8f\xec\xf3\xc8~\x8f\x1c\xf0\xc8A\x8f\\\xe3\x91C\x1e\xb9\xd6#\xd7y\xe4z\x8f\xac{d\xc3#\x87=r\x83Gn\xf4\xc8M\x1e\xb9\xd9#\xb7x\xe4V\x8f\xdc\xe6\x91\xdb=\xf2>\x1e\xb9\xc3#\xef\xeb\x91\xf7\xf3\xc8\x11\x8f\xbc\xff\xff\xfd\xf9W\xf5\xa7\x9b\xb1\x1f\x01PK\x03\x04\x14\x00\x00\x00\x08\x00a~OU+8F\x0c\xf16\x00\x00\x18\x89\x00\x00\x0c\x00\x00\x00font_ext.ttf\xd4]\x07`\x13\xc9\x15\x9d\xd9]\xed\xae\xdaJ\xab^,Y\xb6\xdc%\xf7\"\x1b\x08\xc8\x92\r\xa1\x84\x9e\xc3vr\xc1\xc6\x180!@\x80\xe3H\xbfKr$!\xbd\xf7\xdeI\x93\xb9\xf4\xde{\xef\xbd\x17\xd2{O\x8e\xbc\x99\x1d\xd9^\xb0\x1d\xd2\x1d\x99\xf5\x9f\xf2w\xe6\xcf\xff\x7f\xfe\xfc\xf932\x84\x12B|\xe4\x16\"\x93\x93\x9b\xf6\xdc\xb5\xf4\xb2\xbdo\xbaH\x08}+JGv\xec\xe9\xec\xd9}\xe1\x97\x13\x84H\x04\x9f\xc9\xe9{M\x9d\xcc>\xba\xe1\x11\xc8O\"\x7fd\xfa\xec\x99\x8c\xf3\xc9\xd4\x04\xfe-\xc8\xaf;t\xf2\xf0\xbd\x0et\xfc\xf9~\x84$^K\x88\xe19<u\xfa$\xca\xfdx\xfe\x82G?|\xec>\x87^\xf3\xaeX\x8e\x90\x96w\xa2\xb9\xb1#3S\x07\x13\xef9\xf4>\xbc\x7fg\xd4\x0f\x1cA\x81\xe3/r\x19\xf9\x06\xe4\x1b\x8e\xdc\xeb\xcc\xb9\xd6\x8d\xce\xbd\x848\x9fF\x882p\xec\xc4\xf4\xd4\xb9\xd7M\xbe\x83\x10\x19\xedJ\xe9{M\x9d;)\xdd\xc5\xb7\x1e\xf8\n\xf03\xc7\xa7\xee53\xf9\x81\xb3\xbf'\xc4\xf18\xe0\xeb'O\x9c>\xf3\x96\x1b~\xf8eB\xbc\x9f$\xc4\xf3\xed\x93\xa7fN\x1e\xdf\xf2\xd1\xe7\xe0\xdd\x0f\x02\xff\xa5\x18;\xbdr\x05\xa3\xa7h\xc1 \xf7 \x0er\x1e9\x89\xd4\x93\xad\xe4\xd1\xc08gx\x88\xcc\xb0\xf0\xc6\xd8\x1d'\xd1\xef;Q\xea\x90_\x80\x12\xdb\x87zy\t\xa5w~\xf9\xdb\xdf\xde\xbf\xdf\xb7\xee\xb7\xc4'_f5_\xb9b~_\xc0\x9f\x10r\xc7I\xf9\x05\xd2\x18\xb2*zY\xfe\x93\xc2\xcf\x04\xd1H\x84D\xa4\xed\xf4\xcd\xd2\xf6;\xde%mg\xbf\xefx\x08~\xbf\x8d\xa7\xdfv\xc7-\xbcO\x17I\x93<\xa1#\x1b\xb7\xed%:Q\xd8\xebW\xaeX\xd4LO\x1d;\x832\xa4\xf8\xa3\x08\xa8\xe3Q\xc9\x14\x1f\xd7E\xa2H1\xfa8\xe2\xc0\x08/p\xca\xb6Z\x90\xde\x83\xf4\x90_,&\xea\x16\x0c\x7fq~\xd3\xee\xf2nR\x04\xdb=\x16o\xa41\xb4\xc3\xdag\xbf\x1e'mg\x12a9\x8c\xd4z3\xc4x\xc9 (\xd9\xcb\xf5\xc2/Z\xf4\x10/y\x10y\x1eyw\xc6\x03\xday\x03(1x\x89\x1b%\x12y\xe4\x95\xdf\x90\x0b\xe4(\xd9\xcc\xeb\x16\x7f\x14\xc6}\xea![\xdfH>\xb8{l\x8e\xd2\xc7\x8cW\xe8\x9bt\x8cr\xfa\xe4\x1c\xd1J\x97\x92\x94\xb4\xb1\xc4\xed\x86\x8b\xba\xacTL\xe5)\xbd\xf4f\xf9\x9dh\xce\x8d\xb4\xb3\xf4fb\xa5\xdf\xc4\x88\x1a\x99k\xa0\x0f\xdf5V)>|\x8c\xe5\x0f\x8e\xcc\xb5\xb0\xfc\x1bu\x82\x02\x8e0\x9e\x9ckfEo\xd6!\x07\xa5\xf8\xf0\xe9\xbd\xd5\n\xf6\xb9=\xa0R\xa3\xed\x8d\xf4\xcam\x15\xe5\xd1s\x12\x19\xb9\xddqP%##\x8c\xe26\xfe3K^A\x87\xe9\x1b\xa4\xe7\xca\xcd\xf2.\xf9\xbe\xf2\x0b\xe5\x0f\xcb\xbfW|\xca\x9d\x94\xbb(/V\xde\xe7H9\x9e\xe4\xf8\x80\xda\xad\xbe^\xfd\x9av\x0f\xedKz\xa3~\x93\xfep\xfd\xa2\xfevg\x8f+\xec*\xb9\x9e\xe2\xfa\x8d\xbb\xdd\xbd\xcf\xfd\x00\xf7\xb7=qO\xd1s\xde\xf3F\xcf\xd7\xbd\x1eo\xc1{\xab\xf7\xedF\x87q\xc6\xf8\x85\xcf\xef\xdb\xe1;\xe6{\xa2\xefm\xbe\xaf\xf9\r\x7f\xa7\x7f\x83\x7f\xda\xff\x00\xff\x93\xfd/6G\xcc\xcf\x06\xba\x03\x9f\x086\x05\xcf\x86\x9aBGC\xaf\x0c\xfb\xc2#\xe1#\xe1\xcb\x91\xd1\xc8\xf3\xa3\x8d\xd1\x97\xc4\xeacO\x8a};\xde\x1a\xdf\x11\x7fp\xfc\x95\xf1?'\xf2\x89[\x13OI\xfc0\xb96yk\xf2\x035\xde\x9a=5O\xaf\xf9F\xaa1u\xcf\xd4\\\xea\xf7\xe9;\xa5\x1f\x92\xfeP\xad\xaf\xf6\xae\xb5\xcf\xac\xfdV\xa69s\xaf\xcc\xed\x99?\xd6m\xa8\xbb\xad\xee#\xf5f\xfd\xbe\xfag\xd5\x7f;\xdb\x92=\x9e}m\xf6O\r\xc5\x86\xf3\r\x1fm\x0c4\x8e5>\xa7\xf1\xbbMmM'\x9b^\xdf\xf4\x97\xe6R\xf3\xf6\xe6\x89\xe6C\xcd\xa7\x9a\x1f\xd8|\xa1\xf9)\xcd/h~u\xf3\x9b\x9b\xdf\xdf\xfc\xe9\xe6\xaf7\xff\xa8\xf9w-R\x8b\xd1\x92hij\xe9iY\xdf\xb2\xa5\xe5\x86\x96\x03-\xc7[\xee\xdbr\xbe\xe5\t-\xcfi\xb9\x88\x9fw\xb6|\xbe\xe5'\xadRk\xac\xb5\xa3u\xa4u\xa2\xf5d\xeb\xb9\xd6\xc7\xb4\xbe\xa8\xf5\xf5\xad\x1fl\xfdz\xeb/\xda\xa4\xb6P[S\xdb`\xdb\x96\xb6\xbb\xb7\x1do\xbb\xa5\xed\tm/k{{\xdbg\xdb~\x94#\xb9H.\x9f[\x9f\xdb\x99;\x90;\x93;\x9f{Z\xeeb\xee\xad\xb9\x8f\xe7\xbe\x99\xfbU^\xc9G\xf2-\xf95\xf9m\xf9{\xe4O\xe6\x1f\x9c\x7fR\xfe%\xf97\xe6?\x9c\xffj\xfeg\xed\xa4=\xd2\x9eo/\xb5\x8f\xb5\x1fo\x7fh\xfb3\xda+\xed\xefo\xffj\xfb\xaf:\xf4\x8etG_\xc7\x96\x8e\xc9\x8e\xb3\x1d\x8f\xeaxA\xc7\x1b;>\xde\xf1\xdd\x8e?u\xfa;\x9b:\xd7u\xee\xee<\xd2\xf9\xc0\xce'u^\xec|g\xe7\xe7;\x7f\xd2%u\xc5\xba\x1a\xf0\x93g?\\\xa3\x9d\xe4\x14\x9b)\x8a\x13\xe9\xf7J\x9f\x16iJ\xd6IO\x11i\x89\x18\xd2\xc3\xad4~OH\x1d\"\xad\x90m\xf4\xdb\"\xed \x1b\xe9\xb3D\x1a\x9aG\xc7D\xdaK\xeb\xc9\x80H\x1bH\xc1\x8e\x933\xf89IN\x935\xa4\x13?\xa7\xc94(\x98E\xc9\x19\xa4;\xf0\xcc\x92c\x80'Pz\x18\xf5;\xc8F\xb2\r3\xf8\x08\xcaOc\x8eoD\xcdqr\x06\xa9=H\x1dB\xeaf2\x05\xdc\x19\x94X\x18\xc7\x00\xa7\x91?NN\xe3\xf7A\x94\xdc\x84\xf4A\xa4O!}\x06-\xcd\xf0\xb77\xa3\xdd\x0c\xda?\xc9pm-o\xb3\xb5\x90G\xc9\r\xecmN\xdb\t\x8e\xdbM:\xf8\x93a\x94]\xdb\xef\x025\xa0\xed,\x1e\x8c\t\xbf\x0f\xe07\xab\xb9\x19y\xd0\xc1jy\xbf\xc3d\x17O\x9f\x01O2\xff$\x87\x18\xcd\x078\x1fJ\x9c\x1f\xd3\xa8gc\xee%Cd\x94\x9c\xc3\xbb3\x16\x17\xf0\xec\xc5oV\xd2Nv#u\x18\xfc9\xc6\xdeYr\x94]\xf8\xe9'k\x19\xe7\xf0s\x08x7\x01\x9e`\xa3\x16\xdcj!g9\xe6 \x9e^\xd2\xba\x88\x92\xccU\xb4d85\x99k\xe8\xc9\xccS\x94\xb1Sd\xa3`\x13\xea\xcax\xd6\xfe[\xc6j\xcb\xfdK4\x97\x81y\x92\xdc\x87\xcb\xe80\x97^\x06\xabY\x17h/\xa0W\xa4\xd8\xc3\xf0-\xcd[\xb1\xaf\x9d\xe4\x14\xd2G\x91\x9e\xe6\xed\x0csn\x1f\xe1\xb2>\xcdx}\x8dv\x1c\x16\xbat\x13\xda\xec\xe0-\xdd\x8b\x97\x9eB\xcb'\x99\x94X\x19\xeb\r\xa5\xc7\xe6{>`\xeb\xb7\x95\xfe\x064V?o&e<=x\x9cx\"x\\x\xbcx\xb6\xe3i\xc7\xd3\x86\xc7\xc4s'<\t\x81\x1f\xc3\x13\xc6S\xc7\xde\x11\xe5\x01Q\x1e\xc7\x93b\xe5\"]\x16\xefzE;>\x81\xe7\xc1\xa3\xb2\xf7DYH\xbc\x93\x12\xb8A<iQ\xef\x17m\xf9D\xb9K\xe0\xba\x19\x1d\xa2\xcc#\xa0S\xb4\xebcx\xa2\xac\x9b\xf5)`V\xb4?$\xda\x8e\x886L\x91\x8f\xe21\xf0$\xf14\xb2\xb2\xea\x98\xaa\xe5\x02F\x04]y\xf1~B\xbc\xebc\xfd\x8b\xf6t\xd6\xbf\x18\xdb.\x01\x13\xf4\x9b\x84\xfc?=\xf2;\xff7\xcf\xf5\xf6\xbd\x80\xb7\x98\xe6\xbf?\xae\xeb\x19\x1f\xbd\x8e\xf7\xff\x1d\x8f|\x1d\xe3\xfco?\x82\xb6\x85\x8fd\x81+\xafc\xf6\xe3\xda\x0f5\xf0HT\xa6\nuP\x95jT\xa7N\xea\xa2n\xea\x81\x17mP\x1f\xf5S\x93\x06h\x90\x86h\x98Fh\x94\xc6h\x9c&h\x92\xd6\xd0\x14M\xd3Z\x9a\xa1u\xb4\x9efi\x03m\xa4M\xb4\x99\xb6\xd0V\xdaFs4O\xdbi\x07\xed\xa4]\xb4\x9b\xf6\xd0^\xdaG\xfb\xe9\x00-\xd0A:D\xd7\xd0\xb5t\x1d\xbd\x13]O7\xd0\"\xbc\xde\x12-\xd3\x11:J7\xd2M\xf4\xcet3\xddB\xb7\xd2m\xf4.t;\xddAw\xd2]t7\xddC\xf7\xd2\xbb\xd2\x1b\xe8>:F\xc7\xe9\x04\xbd\x1b\xbd;\xbd\x91\xde\x83\xee\xa7\x93t\x8a\x1e\xa0\xd3\xf4 \x9d\xa1\x87\xe8az\x84\xce\xd2\xa3\xf4\x9e\xf4\x18\xbd\x17=NO\xd0\x93\xf4\xde\xf4\x14=M\xcf\xd0\x9b\xe8Yz3=G\xefC\xefK\xefG\xefO\x1f@\x1fH\x1fDo\xa1\xb7\xd2\x07\xd3\x87\xd0\x87\xd2\xdb\xe8y\xfa0\xfap\xfa\x08z\x81>\x92>\x8a>\x9a>\x86>\x96>\x8e>\x9e>\x81>\x91>\x89>\x99>\x85>\x95>\x8d>\x9d>\x83>\x93>\x8b>\x9b>\x87>\x97>\x8f>\x9f\xbe\x80\xbe\x90\xbe\x88\xbe\x98\xbe\x84\xbe\x94\xbe\x8c\xbe\x9c^\xa4\xaf\xa0\xaf\xa4\xaf\xa2\xaf\xa6\xaf\xa1\x15:G/\xd1\xdb\xe9k\xe9\xeb\xe8\xeb\xe9\x1b\xe8\x1b\xe9\x9b\xe8\x9b\xe9[\xe8[\xe9\xdb\xe8\xdb\xe9;\xe8;\xe9\xbb\xe8\xbb\xe9{\xe8{\xe9\xfb\xe8\xfb\xe9\x07\xe8\x07\xe9\x87\xe8\x87\xe9G\xe8G\xe9\xc7\xe8\xc7\xe9'\xe8'\xe9\xa7\xe8\xa7\xe9g\xe8g\xe9\xe7\xe8\xe7\xe9\x17\xe8\x17\xe9\x97\xe8\x97\xe9W\xe8W\xe9\xd7\xe8\xd7\xe97\xe87\xe9\xb7\xe8\xb7\xe9w\xe8w\xe9\xf7\xe8\xf7\xe9\x0f\xe8e\xfaC\xfa#\xfac\xfa\x13\xfaS\xfa3\xfas\xfa\x0b\xfaK\xfa+\xfak\xfa\x1b\xfa[\xfa;\xfa{\xfa\x07\xfaG\xfa'\xfag\xfa\x17\xfaWz\x07\xbd\"\x11\x89J\x92$K\x8a\xe4\x90TI\x93t\xc9)\xb9$\xb7\xe4\x91\xbc\x92!\x95w+\xdb\xef\xbam\x9b\xf7\xc0\xcc\xb1\x137w\xdct|\xb6\xab\xab\xa7\xdb\x96\xeb\xb1\xe5zm\xb9>[\xae\xdf\x96\x1b\xb0\xe5\n\xb6\xdc\xa0-7d\xcb\x95l\xb9\xb2-7b\xcb\x8d\xdar\x1b\x17\xe7z\xbbl\xb9n[\xae\xc7\x96\xeb\xb5\xe5\xfal\xb9~[n\xc0\x96+\xd8r\x83\xb6\xdc\x90-7l\xcb\x95l\xb9\xb2-7b\xcb\x8d\xdar\xb6\xf1\xf5u\xd9r\xdd\xb6\\\x8f-\xd7k\xcb\xf5\xd9r\xfd\xb6\xdc\x80-W\xb0\xe5\x06m\xb9![n\xd8\x96+\xd9re[n\xc4\x96\x1b\xb5\xe5l\xe3\xeb\xef\xb2\xe5\xbam\xb9\x1e[\xae\xd7\x96\xeb\xb3\xe5\xfam\xb9\x01[\xae`\xcb\r\xdarC\xb6\xdc\xb0-W\xb2\xe5\xca\xb6\xdc\x88-7j\xcb\xd9\xc67\xd0e\xcbu\xdbr=\xb6\\\xaf-\xd7g\xcb\xf5\xdbr\x03\xb6\\\xc1\x96\x1b\xb4\xe5\x86l\xb9a[\xaed\xcb\x95m\xb9\x11[n\xd4\x96\xb3\x8d\xaf\xd0e\xcbu\xdbr=\xb6\\\xaf-\xd7g\xcb\xf5\xdbr\x03\xb6\\\xc1\x96\x1b\xb4\xe5\x86l\xb9a[\xaed\xcb\x95m\xb9\x11[nT\x9d>qp\xa6c\xd8\x02%\x0b\x94-0b\x01\x81\xb2\xd1\x02\x9b,pg\x0bl\xb6\xc0\x16\x0bl\xb5\xc06\x0b\xdc\xc5\x02\xdb-\xb0\xc3\x02;-\xb0\xcb\x02\xbb-\xb0\xc7\x02{-pW\x0b\xdc`\x81}\x16\x18\xb3\xc0\xb8\x05&\xdc\x1c\x1c<q\xec\xd8\xd4)\x17O\xcf\xcc\x1e>r\xc6\xc9\x93\x87f\xcf\xce\x88\xd4\x89\x9bD\xf5\xbdf\x8f\xdft\xda*<>{|F\xe7\xa9\x13\xc7g<<qr\xe6\xd4\xf4\xcc\xf13\xeejf\xf6\xc4A\xa7\x95>v\xd3i\xab\x81\xd33gg\x8e\xebVr\xf6\x9c(;6u\xfa\x88H\x9e\x9c\x9a\x9e1\xac\xe4\x99\xa9SgN\x9f9q\xd2\xaa9s\xe4\xd4\x8c\xe8\xef\xcc\xcd'\xacf\xef;s\xea\x84\xc6\x05\xd0\xd5-`\x8f\x80\xbd\x02\xf6\t\xd8/\xe0\x80\x80\x05\x01\x07\x05\x1c\x12pX\xc0\x92\x80e\x01G\x05\xdch\xc1\xee.\x01\xbb\x05\xec\x11\xb0W\xc0>\x01\xfb\x05\x1c\x10\xb0 \xe0\xa0\x80C\x02\x0e\x0bX\x12\xb0,\xe0\x88\x80\xa3\x02\x8a\xfe{\xba\x04\xec\x16\xb0G\xc0^\x01\xfb\x04\xec\x17p@\xc0\x82\x80\x83\x02\x0e\t8,`I\xc0\xb2\x80#\x02\x8e\n(\xfa\xef\xed\x12\xb0[\xc0\x1e\x01{\x05\xec\x13\xb0_\xc0\x01\x01\x0b\x02\x0e\n8$\xe0\xb0\x80%\x01\xcb\x02\x8e\x088*\xa0\xe8\xbf\xafK\xc0n\x01{\x04\xec\x15\xb0O\xc0~\x01\x07\x04,\x088(\xe0\x90\x80\xc3\x02\x96\x04,\x0b8\"\xe0\xa8\x80\xa2\xff\xfe.\x01\xbb\x05\xec\x11\xb0W\xc0>\x01\xfb\x05\x1c\x10\xb0 \xe0\xa0\x80C\x02\x0e\x0bX\x12\xb0,\xe0\x88\x80\xa3\x02\x8a\xfe\x07\xba\x04\xec\x16\xb0G\xc0^\x01\xfb\x04\xec\x17p@\xc0\x82\x80\x83\x02\x0e\t8,`I\xc0\xb2\x80#\x02\x8e\n(\xfa/t\t\xd8-`\x8f\x80\xbd\x02\xf6\t\xd8/\xe0\x80\x80\x05\x01\x07\x05\x1c\x12pX\xc0\x92\x80e\x01G\x04\x1c\x15P\xf4?,\xfa/\xf7(\xf7\xbd\xf9\xf8Q\xed\xbe7s\xcbAH\x85\xe43\x15r\xd7\xb1\xd1\xf1L\x06a\x7fc\xd7\xd6\x8a\xbagb\xac\xd2\x97\xac\xb4\x8cO\x1e\xca\\\xb8\xebXEj\x9c\xb2\x0e\x01\xa6\xb3\x07\x92uu\x152^!\xe5\xec\xc8%\xc4Q\xcb\x93\xa5\xf6\n\xcdW2\x93\x87\xda+R>[\x97\xadk\xaf\xc8\xf9\xcc\xc1\xdb\xe5P\x98\x94\xca\x95`939Y\x9a\x93B\xe5\xd2\\\xa3\\\xaeH\xe5\xbd\xe72\x15O\x16\x89\xf2\xd4\xc1\x8a\xb2\xf3\xdc%\xb8\xd0h\xa6R7SS\xc7J/\x19aZ\xaa\xc9 \x99-]\n\xd2 \xea\xb2\x15\xb2slf\xfcR\x84J\xbcC%_\x91s\x95py\x8c\xf5W\x89\x94\xcb\x02!\x999\x98\xa9\xbcsgEi\x9a\xb8\xd4B\xbd\xe5\xd1\xe9\xd1\x8a::VW\x91\x1b\xc7w\xdfm\x0c\xc8\xc9\x0bc\x99\xca\xce\x9d(*\x02\xbb2\xc8R\x83\xe3\xe3\x999\x0b\x1b\x14\xb5\xa0H\xe42\x95.V\xdf\x05L\xb4:\x96\x017.Le*\xae\x9dc\x93(\xc9\xb0:\x17K\r\xb0\xd4\xc0dr\x12\x87\x15Ip\xab\xe2)OW\xc8\xee\xb1\n\xd9\xca\x90\xeb\x90On\xad\xa4Y*\xbdu\xea\x8d~2\xcd0\xde\xe8 \x07\xc6\xc7\x0fN\xe1\x88%7>n\x8d\x00\x94\x1c\xacD0\xf0\xf1\xf6\x8a#\x9f\x01\x05J\xe3\x14\xc6\xa4\x95w\x8eU\xb4l\xa9\xa2gK\x90\x00^\x99l\xaf\xa8\x9c\xdd\xe0D\xe6\xe0\x9cv\xa0\x94a\x95l\xb8I\x8b|\xf6\x1bx\xa3\xd3\x15G[\x1d*\xcb\x99\x0b\x99\x0b\xe8k\xae\xcb\xd1\x08\x0e\xed\x1a\x9b\xdc\x99\x9c\xda=>\x96\x1d\xaf\x1b\xcfT\x8a{\xc6P\x97\x04_\x04)\xa0@\xcbW\x9c\xe5\xdc%\"Yb\xd6\x91\xcd\x96\xb2P\x97li\xaa\"\x1d8T\xa1\xd3\xe8\xa0\xa2\xb5\xb5W\x9c\xf9\x0c\xa3\xd6\xc0\xb0\x14r\x00(\xa0\xb789\xceP&G8\xb5\xae\xfc%\xa7A\xca\xa3\xa5\xb6\xbay\xc5q\xe7\xed\x8a\xe4\xe1\xad\x80\x8e,\xca1\xf4\xc9\xcc\xe8\x85\xecT\xe6\xa0`6I2\x81T2I\x10Y\xa5\x12\xa2\xcdN\x8dX]x\x97y\xbd\xd2\x80\xb7\x08\xdeZ\xea%#\xcf\x07t\xbb\x17\xc7\x93\xa3\xe8%\x99\xad\x1bo\x83\x12\xfb\xf2s\x924Z985\xd2^\xf1\xe7\x81\x9a\xc9T|\xe5-\xac\x01$ \xa1\x8a\x9f\xe5v#\xe7\xe7\xf22\xf3Hq\xa6d\xc0\x83i\xf4\\1\xcb\x93\x99\x0b\x93\x99\x8a\t\xb6\xb5W\x02\xf9\xad{\xc7\xe6\x94\x83#\xe3\r\x15\xefL\xf6\\{%\x98\xdf\xbakl\xeb\x1e\xab0Y\x87\xf2 /\x0f\xe5\xe7H\xa0|\xd7\xb1\xb9@\x00\"\x9c*U\xcc\x1c\x9brP\xad\xd2\x9c\x8f\xfd\xf2\xe3W\x85F\xb2\x19\x8cd\xe7\xd8\x1cc\x1f\xc6[\xbap!\xc3\xba\xf5\xb7\xd5e\xf1Z5\x9d\xe4\xf5\xece<\xbcd\x1c#\xd9\x04\xfa7\xa1\xd4.\xaceD8GH0\x0b~\x95+d\xfd%J)\x97V8O\xe6\x884\xbaw\xac\x12\xc8\x962\xa3\x15\x03\xea\xe7E\xc7\x93\xa5\xcc\xe4\x1bb1JL\x84\x02K\xa5\x12\xe3@\x08utj.\xa4\xe7*\x8f\xcc%\xeb\xc1\xae\x08\xc6\x18\xce\xb5W\xa2\xf99\xca`\x0c\xfcf0\x9e\x9f\x93\x19L\xe4\xe7\x14\x06\x93\xf99\x07\x835\xf99\x95\xc1T~Nc0\x9d\x9f\xd3\x19\xac\xcd\xcf9\x19\xcc\xe5\xb3U\xfeW\xd4Ip:\x9b\xe9\xa8\xd0\x1b1[\xd0Y~Qed\xbe\xf2\xdeVe\xfb\xa2\xca\xa6\xf9\xcaSVe&O*\xbe\xdc\xb2\xe3\xc4\xa0^g\r\x95\x8ds\xf1\xf8\xea0\xbe\x0c\xe8\xaa\xc7\xf8\x18\xccb|\x0c6`|\x0c6b|\x0c6a|\x0c6c|\x0c\xb6`|\x0c\xb6b|\x0c\xb6a|\x0cv\xe43\xeb\xb8\xc2v\xe6\xd1ml2Sf$\x94\x99H\xd9$\xec`:\xdb\x95\xaft\xe6*\x9d\x98\x8f\xdd\x98\n\x9b2\xcbH3;5\x98e\x86}E\x8c$\x1b}OU\xc4s\x86:\xca4\xae\xd2\xdd6\xe7\xa0\xe1\xd1\xb1\xaeq>\xca^\xce\x9e\x95q\xfa\xf2\x99~Ny?Z\xb3pF\xaf\xed\x13\xd3V\xd0rm9\x89\xbc\x96\xb0\xcf\xc8\xfa\xec\xe0\\\x1f\r\xb3\xb1\x0e\x80\x1f\x99M\xcb\xd0\x8f\xc925\xd8^)\xe4;\xa2\xeb\xda+\x83\x7f\x0f\x15\x8a=\r\xf4!\x88\x88D\x1a3\x1d\x99M\xcc$\x80\xb5\x9b/\\\xd8\x94\xdd\x04\x1b2v \xc9\xac.V\xa4AJ\xc3!pxM\x1edU\xa2@S\x1a\xf1\x8f\xa3\xcdyH\xa9\xe2.\xe7f.td3\x99u\x17\xd0\xe6Z\x1b\x1a\xda\xb6\xda\xab\xa8\xd9R\x15;S\x99d6\xa5\xb8k\xecv%\xe3\xc8$oW\x9a\x1c\x89\xf1\x12\xb3\xb4\xae2&1\x7f#\xbbq\xb2\xa2B\xdaWQ\xcf\xac\x9d\xb5*)\xe5\xc9\x83\xd9\x8a\x03\x8b\xea\xce1d\xa6\x92HO2Kw\xf5;S \r\xf6?\xbb\x112\xce\xa2\x87\x8d\x18'\x00\xef\x05\xed-\xd1I\x96\xdbT\xd4L2a8\x1a\xa7\xf0\\\x8d\x84\x16\x19\x11\x8d\x8c\x08\x19\xbf\x85%]\xe8\x0b\x8a\xb0\xae\xca\x8b\x0cJ\x1dM\x82\x17\xd9u`\xd3\x9d\xaaU\x183\xaf\xdf\x98\xdd\xc4:eR\\_\xad\xe3\x83\xb18]!{\xc7:2\xeb\xb0\xa0\xa3\xa4Z\x88F\xe7EQQ\x1b\x91\xdb\xbc\xd8w\xb1\x84\xb8\x94\xb6\x0bie\x99\xcaoXDI\xb9*\xaeI\xe6\xe0\\=\xe4\xaa\x88\x8by\x18\x0c\xc6\xc5\x8d\x95hylg\x12kjf\xddx\xc7\\\x17\ra\xde\x0e\xdbjw'w\xdajKK\xbe\xbb\xd2\x1b\xe5|eMn\xa5\x0eG\xf2\x95\xb5\xb9\x0b\xa0\x8d\xe9\xd8\x85\xc1\xe5Q!\xd0\x8eJ\x17\xde\x18eC\xe6\xfa\xd9dq~\n\x0eZ\xc9\x1a:S\xd0,\xa6OGvP\xb4\xbf1?\xe7\xc2Z\x83W\xfe\x19\x95\xde\xf4\xef\xd2b6&f\xc7\xd6ea\xaa\x16\xe9K\xdd\xb8\xa0s\x13\x0c\xf0\x9a\\\x95+wFnm\xae.+\xf8b\x8df\x81\x05\x9b\xc1\x82\xb05\xed/\x116\xc3\x83\x1d\x95\x01\xcc\xf2-\xcb\x94oEs4\x14\xac\x14\x90\xde\x96\xaf\x0c\x01\xdc\x85qq\x14\xec\xcel\xc4\xc2[\xe5\xd6\xf6<S\xe8\xca]\x90\xdc\x91\xbfD\xc8F$v\"AYbW\xfe\x12\xe5%\xbb\x91\xe0%{\x18\xce&$\xf62\x1c\x96\xb8+\xaax\xc9\rH\xf0\x92}\xf9\xdba\x0b\xcbH\x8d!Eyj<\x7f;\xb5\xca&\x90\xb2\xca\xee\xc6\xf0(K\xdd\x9d\xe1\xf1\xd4\x8d\xa8\xb5\xca\xee\x81\x94U\xb6\x9f\xf59\x8a\xc4$\xeb\x93%\xa6X\x9f,q\x00\t^2\xcdp\xee\x8c\xc4A\x86\xc3\x123\xa8\xe2%\x87\x90\xe0%\x879]#H\x1da\xfd\xf1\xd4,\xeb\x8f\xa7\x8e\"e\x95\xdd\x93\xd3\xc5R\xc7\x18\x1eO\xdd\x0b\xb5V\xd9q\xa4\xac\xb2\x13\xe0\xf1\xbay\x01\x9e\xe4\xb9J\x11\xc9{[\xc9a$O1\xa6\xf3\\\t\xb9\xd3Xk\x05\xce\x19$\x05\xceM\x1c\x87\n\x9c\xb3x\xf9N\xf3\xad\xde\xccr\xd6\x1b\xe7X\xd2z\xe3>,i\xa1\xdf\x17\xed\x08\x84\xfb!)\x10\xee\x8f\xa4@x\x00p\xd7\xcf\xb7\xf7@\x96\xb3\xd0\x1f\xc4\x92\x16\xfa-,i\xa1\xdf\x8a7\x05\xc2\x83\x91\x14\x08\x0fAR <\x14\xb8\x1b\xe6\xdb\xbb\x8d\xe5,\xf4\xf3,i\xa1?\x8c%-\xf4\x87\xe3M\x81\xf0\x08$\x05\xc2\x05$\x05\xc2#\xf3\x97\xdc\xdc\xb3\xad\xa8\xc9K\x8a$\x8fb\xd3\x0438^\xcaU\xf4\x99\x8a\xdc\xb0\xf3\\u\xb1n\x87\xa3\xdfs\xc7I\xfan\x89\xddo\xd1H[\xb1\x99\xdd6\x93\x88|\x18\x07\x1dT\xdaG$\x89\xeeW\x90\xa2;\x08\xd1T\x87\x024\xd9t\xa8\xd1\\\xd0\xac3\x1b\xeb\xcc\xba\x1e\xfa\xb8;^@\xf3w|\x16\x97\xf3.\xff%\xd6#?\x94m\x1e\xae\xfc\x05'\xf1\x7f\x80\x11\x8e\x91\xceb>L%\x99nc\xc7g\xb88s\x18\xedK\xf28\x91eiJA\x85\xb4\xcb\xe5\x0c\xf8\x9d1W,\x90u\xa8\xb1\\\xa1\xaf0\xd0\xdb\x13\xd6\xb2\xd1\xfa\xe6\xa6~\x9e\x89F\xc2!M\xdd\xe4p8\x83\xae\xa0\xd3\xa9\xa9\xaa\xe6t\xaa\x9a\xa6~\xcd\xabi\xb5\x8f\xdf\xa6j\xbaS\xc3\xc7\xa9k*\x1b\x11y*y8\xf9=q\xe3\xac\xba\xb7\xd8eH\x12Tn\x9bCVdvSq\x1fOP\xb2_b7\xf8vx<\xb8@\x17\xf5D\x03&\xf0\xdda\x15C+\x8444\x9emnB\xff\xbd\x8b\xd2;\xc1\x07) \x8117\xcc\xa7~_\xeb3\x02\x81\x80\xe9\xf3\xd5.\xa4@\x03\xbbM4G~\x88\x93\xf4Z\xf2\xc1\xad\x95\xe0\xce\xb1b\x8fNU\x87C=\xe9\xa5\x8c\x8c{;5\xc9a\xb8$Ev(G\xfc>\xb7,\x83\xf1\xfbX\x02\xa9\xfd\x1e\xd0,\x93\x1d\xd8C\x86\xf0f\xf7\xa27\xe9\xf9\xebz\xb1\xd8\xc5\xdeQo\xbb\xfeW\xc6\xc7\x8b\xe9\x9a\x9a\x9a\xda\x9a\xdat*\x99\x88\xc7\x18\xd3\x83\x01S|\xfc\xa6Z\x9b+d\xb5l![\xe8\xe5OA\xe3\x8f\x96\xe5\x8fV@\xe5\xbd\xda\xf4\xb0\xd6 5j\xb8H\xa6E\xf5V=\xaa\xd7K\xf5z\xa3\xd4\xa8G]z\xabv\xe7r\xc9\xdc`\x16iq=]\x1fXo\x8e\xd0\xbd\xc5\"\xba\x8e\\\xf99y\x05\xf9\x15n.\x0c\xe2~Hk\xb1ixh\xb0\xa7\xb3\xb1\x81\xd1\x11p9\xa1\x8e&\x06\xb1\x8d]]\xbc\r\x92<\xdb\xdd\x15\nJj$Whj.\xf4DC\xd1H\xb4\xbf\xc9R\x95B\x7fo\x0fS\x95p8\x12\xd5P\x86\x1f\xa4\xb8\xf6\xe0'\x9c\xed\x07\x08\x87\xa2\xd1\x81\xc2@\x7f\x1f*\xf75'\xfc0=\x81\x9a\x94\xcf0\xfd\xf1\x18\xf4<\x1bb%\xd4\x13\xad\xf3\x19\xbaf\x18\xc1\x88_w\xd6EL\xb7\xcb\xe9\x0c9\xe4d\x04\xca\x13\x94w\xbb\xbcF(\xe4\xf3)\x11\xa6\t\x92\xa1\xc4CT\x96\xa9O\xb9\xb3\xcb\xeb\x8d\x1a^\xaf\xcb)E\xbf(9uw\xd88*\xbb]\x86W\xd7U\x82[e.\xcc\x8c\xdb\xc9Op\x9b\"\x8e\x9bE\x1bp\xd7\xe9\x07<bP\xbc\x13&\x9c\x83J\x0e\\%\xd6U]V\xd9\xf5T\x07N\x99g\xddTqQ\xa2)d\x16\x13\x14\x1a\xee\x9c\xf5R\xd4\xeb\xe3\x00\xbaz\xc0CU]\xdd\rEq\xa3\x91N\x89\xae\xf8\x96l\xbd%\x1f\xf0\xa8\x92\xac\xcb\xbb\x93\xffb\xb7\xd0\x99\xe6\xe1b\xae-\x99\xa0d\xf3\xa6\xe2\x8e\xe1\x1d\x85\xfe\xb6\r\xb9\r\xd9\xbaDk\xb2\x95\xe9\x90\xd7M\xc24l0i\xd57\x0b)\xf1)-\xc4R\xe8\x85J\xf5X\xe2\xc8\xd63\xe9\xa0\xc6\x86Y\x15_\xf3UX}\x90\x88\x8a\x8f\xd3\xe5v\xbb\\\x0e\xd5\xe3\xd9\x1ayp(\xab;0St\r\xba\xef\xb8\x07/W\x1d.\x97\xdb\xf4x\x1c\x0cSWY\xad\x13\xa5\xea#U\xd5\xed\xf1\x1an7\xe67K\x85\r\xef\x8d\x97\x9f\xa3\xe9\x86O\xc3\xc7gh\xfa\x0bP\xee\xe6\x18\xc8\x86\xbc\x0c\x06Q\xef\xd5\xc1\x0e\xc3\xa7k\xec^\xae\x97\xcb\xf3G\xb8!\xb3\x067\xaa\x8a\xc5;\xad\xbfS[Kc]\xc6\xd0e)Ga\xea\xb6\xe5\xc1\x1a0\x15\x16P\x9aU(\x9by\xe3\x002\x99b\xaf\xefZ\xb7v\xed\xe8\xba\xd1\x81\xbeh8\xeb`\xa6\x07\x03\xcd.\x0c\xff\x1aviLua!\xa3Hi\xcd\x036\x8e\xf4\x14\x9aU\x8b5\xe7\xdd\xa6\x19\xf0{1\x04\xaf7\x9c\xd04\xb7\xc70<n6J\xb3\xd5\xa9\x80\x90\x98a$\"\x9b\xbd\xba\xa6\xe9.\xb7\xa6\xfbb\x91N\xc3\xa9;]5>\x8cM\xf7x}\xd1P\xc8[\x9b\xc0\xd0\x99\xf5\x03\x13\x02\x81\xa0\xb6\xd6\xad\xebnI2c\xc1z\xffcU\xdc\x95\xf5\x00W\xf3\x04\x9e\x98(:}>\xc3\xefrc\x98\xdba{\x8fq\xdb\xdbX\xac\x97(3\xbc\x12\xe5f\x17\x00F\x97Mb,%\xdc\xd6\xcaW\xd9\xdacKYU\xe0\xb7_y\x07y\x06\xda\x0c\x13\xf5v\x0f\xa1=\xb9h\xd3\x82\x82\x80\x15Bk\x9eX\x1b\x8dz\xbc^O$\x9a\xd6\x1a\xc3\x91H\xa4i\xd8\x88\xc7\xd3\xb5uu\xe9t4fDC\xd9\x86\xd6\xb6\x86\xc6 ZlC\x8bO\x15-\x86\x9dhq\xde\"\x14\"\xd1\x05\x83\xd1\xd6\x84t\xa4AKE#l\xb8\xd1hm[\xb0\xb1\xa1\xad\xb5!\x1b\x8a\x1a\xb1h:]WW\x9b\x8e\xc7\r\xc2\xa2\x01\xcd\xb8\r\xfen\x8c\xab\xa9\x98esJ\xda\x87EF\xc1d\xa2\xe40VQ\xc7~\xe2\x90\x1c;,[\xaa\xaa5\xb0\xa5\xfd\xbd\xfd\xbd\xe1\xdep6\x9c\xddS*E\x8b\xc5\xe8\xb1\xe8\x86\r\xd1Q\xc6\xa1;]y7n\xb35\xe1\xfe\x95\xaf\xe8\x89P~o\xfbl'U\xa3\x0b\x846\xd9\x16\xc7;\xb95\r\x9d8d\t\x13\x02\x12m\xe9uB\xe0\xb2$+X\xed\x14\x97\n\x9d7R-h9A\x8e\xe0^\xf8\xadP\xbdX1\xcc\xae\xdc\x93}l]\xde\x8f*\xba\xc3\xf4Kl\x01\x06M\x89\xf3\xe7o\x8d\xa3\x9c\xaf\xe4\xc7A\x89\x8f4\x14\xeb<\xd4\xb2\xc3\x00\xe3\xec\xad)\x89\x15\xec\xe2_\x81\xf053q^\xbdf\x8f\xe9l\xb1\xd6\xf9b\xad\xf0\x04>l\x99fm\xc7\xae\xfc\x82\xbc\x00R\x90!\x05\x992)\x14\xa2Z\xecL\xe4\x8c\xe3/\xee\xbf\xa04\x8c\xbe_\x8c5\xd4\x07\xaa\xb3dCq]}]\x14\xe6W\xa2\xdb8_%\x99H\xb3*\xc5\x9b\xf2\xb8\xca\xac\xef\x14AfWM\xd2\xf4S\x92\xcc\xd6d\xfd\t3\xe1\xd4\x88\x8f\xfa4f\x7f\x04IYAb\xd4\x9a5\x050R\xb3L\x8b\x16\xb9\xb1>\x18\x0c\x06\xb2\xd9\x00@}\xd8\xe3\x91w8\\N/Klw\xff\xb06S\x18\xaa\xc5g\xa8\x90\xa9\x8d\xc6\x13\xf9x\xe0\x90\xe9r\xbe#\x16\xef\x0c\xfbg\xd8]\xfd:0\xe2$\xb9\x8c\x9bq\x99bJ\xc2\xe4g\xdc\xba\x86\xc7A\xcec\xad\x99\xb1\xf9\x86Nu]0\xf1A\xc3\xc8\\Fe\x04X/\xc4xs\xa4\xa3\x98k\r\x05d\to\xc1Y\xda\x86:\x82\xf6faDd\xee\x93\xc9\xfb\td\xbb#\xb4&\xd7\xa6\xa8\x89\\\x01\xd3\xc0f\x0b\xc2Zs\xb3\xcdxjZoO\xef\x00\xeb2\x99N\xfb|N\x98\xc2@MP\x91\xa4\xa0;\x18\x8c\xa7\x82\x01\x17\xa6p2~\x83\x8af\xa5\x87\x87\xd3\xe9\x00\xd44\x18q\xb9\xa2*\xb3\x17\x92/\xe2\xf6\x04\x02\xe9P0h\x9a\xc98\x95\x12L~\t\xc8\xe7\xb9\xa0w\x90\xdc\xb98\xda\xd8\x00e\xeb\x84P\xe2\x0e\xf6\x86\xbc\r\x8b\x1d\xf37f\t\xc4\x84Q\xcc\xf2\xaf\x89\x8c3nL\xa9\xcc\xf3\xdaEIK\x13\x1c\xd3D4\xe27\xc8 \x1ddB\xe2\xa6\xbfP\x88F\xac\x9f\xde\x05\x9b\xdf\xbf\x90l^\x18\xd8\xfc\\\x1d\x0f\x98~\x8f)1#\xa3h\xb0S\x11\xb7\xdb0\xe2\x8a^\xe7\xf18\x9d\xbeX\xc0\x1f\xcd\xd6\xf8\xfdN\x97\x19\xf2xt\xa7\xcf\xafh\xaa7\x8ck<\xf8\xa7\xca\n3\x1an\x0f\x85\xa0#>\x97\xd3\xf4\xc5\xfc\xbed\xc0g84\x9f/\x12\xf4\xf9\x9d\xec\xcex\x00\xd2y\r\xa4\xeb\xc2\xcd\xca\x81b\xaf\x87J\xf8!\\:\x92B\xf7\xa9\x0e\x88\x85\xe2\xfb \x98\xee\xa0a?Q\xa8\xb2\xc3\r\xd3\xe9\xf6\x9a\xcc\x1akj\x92\xcd\xf9\x82\x98\xf28\xf5:{\xf0h$\x95\xaa\xd98\x14|\xd63\xc2C;\x8e\x1e\xe5s\x82\xeb\xfce\xdcm\x1d)\x0e\xd7caN\xd58\x14\x85\xb2nd\xc2&\xf3a\xe2`\xe6eI~6f\xeb20HQ\x9f\x97t\xd2\xce\x05~FC\x0b\xec\\P\x13K\x05\xb5\xc5\xab\x8bzc$\x10p\xc78\x13\xa1\xf8\x1e\x97[U\ro\xd8\xedq;\xfd\xda\xd9I9\x10\n1n8]~Sq:\x03&e\xfc\xc3\x8a\xa2j^\x8f\x19\xf7\xf9T\xd5\xa5\x9d\x8d\x95\x9c\xf0\xe8\x03\xd1\x98\x19\x00\xe3\xc0\xb98\xc6\xf4B\xf2#\xee\xefl+nf\x9c\xf3B#\xd6$$\x0ch[um\xc4\xf8\x1cP\x98Y\x8d}\x1bI\x19\x07P\xf8\xc8\x14\xb2+\xd7FI\x7f/s,jS\xe1\xa0\xdb\x89\xfb\xbd\xad\xba5\xba\x85\x15Rc&Q\x8cL\r\x0b\xed\xbf\xcayX\xa8\xe7\x1c\x99\xc2tw\xb9\x02\x98\x00\x91 \xd3\x1c\x87nx<p\xdd4\xc3\xeb3}lE\xd4\xfd>\xd3t{\x98\x97\xe1\xf2Bs(\x9c\x06\x97\x92J\xf7\xb6\xa4R>_8\xc2\x15\xc8\xa1\xe9\xa1P=\xb6\"P/3\x82\x9d\x04\xa6\x8d\xcf\x88\x07<\xec=\xa7WU\xfc~\x9f\xcb\xc5\xa4\x9b\x82\x0e=\x1f\xd2\xd5\xd9NK\xe5\xab#\x86N\xa4\xf3\\\x98\xfb\xc8\xe2\x15\x12!,3\xa0\xc0V\xf4\x0e\xb0\xb5\"\xacjk2M\xd3\x0f\xed\xa89:\x13\xf7\x9d>\xc4\xfd\xe6\xbf\x90\x17\x91\x1f\xc36\xf6\xe2\x06\xf2Pq`]\xc2%\xc3<\xce\xb3\xd4a\xb9\x1b\x0e\xeen(\x94\xf9\x1b\xfd}\x94\xf4\x95\xfb\xcb\xed\xd8\xc0\x91,\xcd\xaa\x82\x8d\x82\x91\x02^;\xbf\x9a\x07\xae\xf2\xd1\xaa\x0c\x15\xcc\xbc1\xec7u'\xdc\r\xbf\xcb\xe5\xf7\xa7\xd3l\xc4f\xc8\x8b\xc9\x87\xc1\x1bN\xa6\x110\x96\xa8\x832\x19\xde\xa8\xe9v{<\n\x16%\xc3\x0c\xa1B\xf7\xf9\xfcq\xbf\xe9\xf7\xc5Lf\x9c\x02(4\xe0\x8a<B\xc7zn\xb8\\.\xa7\x81f\xef\xefv\x07L\xe6\x9d\xc1\xd7\x08\xb8=\x0b\x9a\xf5C\xac\xbd\x05\xb2\xbd\xb85O\x15G\x8cb:\xc3\xfex(\xa6\xe56\xf0\x18ZE,\xadb\xd3}\x96\xefk\xc7\xd9\xbev\x8a\xdd\xe4\xdc\xd5\xdaBIwgK\xa1\xb5\x90Jr\xddj\xa6\xcd\xba\xb5\\T\x07_\xcffPu\xfe\\\xe5\xa1\rDYY\xd3\x02c\xee\x1e6\xb1a\x08\x85\x1b\xeb\xa1S\x98\xa8._\xdc\xf0\xcaN\x98\xa3\xa0\xdf\xe7\xc4\xc7\xe7\x0f\xfa\xe1\x88R\xb7;\x12\xf4\x80\x0b?\xf4x#\x91\xd4H6K-u\x92\xd5X\xbcAW\x14\x86\x19\x0e\x9bP\xa6\xfb9\x14wk(h\x18\xb1\x88\xd7;\xbf\xbb~6\xd6\xc5Z\xd2_\xec\xa9\x11\xbbk\x85\xb2\xed\xf5\xec\xa2\xed\xb5\x83o\xafM|\x830\x1e\xf5\xd7\x9a\xb5|\x99\xe6;\xdc\xfa\xab\xe4\xbc\xc4\xb2=\xbf\xa9v\xaa\xd5\xb4zZUY\xd6\xfa}3\x07(\xb5\xd6s\xc9\xf2Z8]Ml\x17\xd7D\xa5\xcd\xec\xba\xe4\xf9E\x0e\x83,\x1c\x86:\x8b\x16e)Z\x96\xf6p\x16\x93\xd4p\xb5\xb7c\xa3\xeb%K\xb9>\xd6w\xe2L\xec3?\x83\xf5Y\xbd]\x95\xe0o\x14\xfa\x0ba-\x1a\xf6>\xfb\xd6\x07\x1f\x0f\xecI\x0eoN\x11\t8\xbb\xe1\xc9\xbd\x90\xc7C\xea\x8b\xb5\x8cl\tQ\x8b\xab\xd7^\xe6\xc7\xf1\xb5\x97\x99s<\xe6\xd3\xf1ya\xb4!\xc2z\xf2\xa1\x95WU{\x92YO\x85\xe6\xfehX\xf3=\xf8\xd6g?\xa7c\xf3prO\xe0Fp\x8c[\xfb\xe7\xc3\x03j\xc5M\xfd;\x15\xd7D\xc3\xd8\x8a\x0f@\x81\xa5m\xa8T\x88\xa4\xdc2\xbf\xf4+\xb2\xac\x8c\x13E\x91!U\x040`\x13{\xbb\xdb\x86rC5\xed9U\x8d\xf3\xa8\xc9b\xe3\xce~\xae\xf1\x02\xd8\xc6\xf8\x9a\xb0\xca^\xac\x84^U\xf3\xb8\x83\x06\xd4R\xa1\xd0\"\xd3\xeb7\x13\xa9@@\x83=T\x1dq/\x93\xb2`\xf0\xde\x80\x9b\x99H\xb7\xdft\xb9\x1d0\xfd`3\xbc\x83\xa0\x0b\xca\x9a\x0c{=\x06[m}\x9b\x17{zl\x9c\x1e\x8c\xf3U\xb0T\xfd\xa4L\xd5\xad\x15'\xb6\xaa\x815T\xd3\x11\x18\xd2z\xa9*\xc1(\xa9\xca\xb6$v\xc2W\xd5\xc8\xa2f)\xf4\xf1q\xab\xa5\\u\xcb\n\x8e\xe9\x9a\xa2\xcf\xba\xa8\x06\xeb\xa7jXS\xd0\xbb:NT|_\xd3I\x91\xd9%\xba\xe8!\x92&k\x92|\xcb\x12\xaf\x12\xacf\xf2\x12o\xfeC\xfd`c\x9c*\x0c\xc0\x91_;P.\x94{\xba\x9a\x1a\xea\xd2\xb1H(\x88\xedp?\xedw/6\xba\x0b+\x15\x8bOd\xe7\xa5\xd3;/\xc9p\xd5\xf8D\xadul\xde\xd6\x1cODX\xac\xc1\x1b\nE\x83\x10\x88+\x82\x15\t\x11\x8b`V\x97\xbdF$\xc8L)lf \x1c\x0e\xbab!S\xd7\x9dJ\xcc\xeb\x05\xe9^#\x99lnN&\xbd^\xa7+\x18L\xec3L\xc3\x08\xc7\xe0\xeb\x18P\x81p8S\x17\x8bB\xca\x01\xdf>\xc3WOa\xc1\r]\x87\x14\xd9 \xc9k\x11\xbb\xd0\xe0\x03\xe5\x8b\xadL\xf8[\xf8\x0e\xe0\xbc\xb5\xaf\xdd\xc7\xf7\xb5\xfb\xd9\xbev\x87\xae\xeb.\xdd\x154\xfd\x0e5n\xc5\x8dz\xa3\xd9\xe6f\xed\xc1[\xa3\x89\xbb\xca7\xc0\x0b\xad\x1d\x19\xf9\xc9O\xc6\xc6\xc6\x80\xce}\xab\x8b\xe42`\x12\xdf\x1e\x1e.\xaewR\x07\xd61\x11\x8b\x84\x93/\x81\xf3\x12\xb7\xe2\x94Z\xbe\x01\xcc72\xbbR5\xa1`]mM}\xaa>\x11\x0b&C\xc9\x8e\x8c\xce\xdc\xeb\xab\x17\xb0,\x82\x0c|jd\xc3Q$\x00\x02\xa5\xa6`\x08\x8eL\x08>_8?\xbc\xbe\xe0\xf5$Z\xdb\x07\xee\xd4t\x19\x8e0\xf8\xa1j~3\x087\xf8\xe1\x8d\xb0\xd6[\xee\x9d\xef\xbc\x1b\x9b\xd7\xd0\xe3Wc\xbd\xc9\x93\xbebwk\x0b,\xc0\xe2\xe5\x96\xf0\xd5\x96T\x17[\xcb#K\xc6!\xf3<\xcd;\x96\x92\xb9\xa65W\xbd\x92\x051\x8b=\xed\xd1D\x08\xfe(\x17n<\x10pFd\xb8'\x88d\xa4\xd9\xf2b\xf8\x02\x86\xc7\xab\x07=pd\xbd\xdeD\xb2\x05\x11\x18\xb6\x96\x84\xdd\x14\x13Rs;\x1c\x89xGM4\xe2\xf1\xb0\x10@\xd0\xe9\x82\xf4B\xf8&\xf0+\xc0c\x0f\t/\x8a\xf3\"$\xc1\x17D\x80\xea\x8ahxC\x01DC\xc2-\x19\x1e\x8e\x15\xca\xc9|\x80\x05&\x86\x06R~\xd3\x13\x95b\xb1\xde\x9e\xae\xbb\x98\x81\xa6\xe4e]\xf7\xa7\x0bC\xa94\r\xdd\xd8\x19\x8f\xbf]\xecg^\x84\x1e\xddL[\xe6\xed(:\x85\xe2\x1c\x863\xebP\xf6\xc1\xa0\xb1\x9d\xb1\xb2hglYT\xf1D\x1es\xf6\xc0\x81\x9b\x1e}9\xba-vC\xb4\xeaA\xbd\x00m:IK\xb1\x11FQ9\xbf\x82\x81f\xda\x97\\h/\x9b\xba\xed\x9e\xfb\xf6%.G7GN\xe1%\x1e\xbby\x05\xfc\xd2vR.\x16\xb1\xf7uH\xf9ff\xcf\xb8@\x1d\x10\xa8\xd8\xc2\x1c^$XU\x086\xd7\xd6\xda\xd2P_\x93\x80p\xdbi\xbb\xb6\x8cp\xc1\xac\x05\xe9\n\xd9\xf6sg\xeepM(\xc4\xb6(\xa1P(\x0c=\x0c\xc8\xcc]q\xc2[L\xb2\x90k\xda\r\xe9\xb6\x95\xea\x14\x9f\x91Ld;\x92I\xb7\xcb\xed\n\x182\x1b\xa2\xc3\xa5(\xe1HwW\"\xa1\xc8Z!z\xb7\x18\xa8\r\xf2\xef\xe3_&a\xb6s\xf4*\x12\xdbx\xb2_2\xd9\x87Z\xec\xc7\x94#\xc8\x12y?\xf3\x08\x19k\"f\xa4\xcakU\x0b\x85\xc3\xbd\xfd\"\x91\xed\x07\x9f\x82i\x89N\xd4J\xb4f\"y\x99m\x08\xb5\xdd\xd3\x1c|\xe1\xf8q\xc6\xb74z{\n\x97ks\xb1\x81\xa9>\xd8E\x0f\xb3=\xb9\x83\xec\x03 L\xa4\xc4.R\x8cZ\x88!\xdd\x91;\xdd\xd1u.\xf2\xd6\x08\xfe\xa1\xb5\xc0\x95\xbf\xf0\xb9\x9fd\xbe\x8c\x0c-d3Jfj)K\x87\x17mr\x1cb\x93\xc3\xa3\xd2~\x8f\x8b$iRx\xaf\x85E\xfeY\xbf\xe8)\xc2,\xe7\x96l\xd8'\xa3E\xc5\xeb\x0b\xea\xce\xf6\xa3\r\x88]\x1a\x86\x92\x08\xc8|\xe7\x82Xm\xe6\xb6H\xe4\xa1)\xcc/\x9d\x8d\xcc\x8f9\xf2\x1a\xcc\xef\x00\x8b\xe2\xf8\xdd.\xaa,\x04\xb0\xc6\xad\x00\x96\xccO\r\x02-f\x80\xaf\xfeZ\x98u\xc7W\xd6B\xa4\xb7\x17Q\xb9\xf5\xc1d-P\xa7\xe0\xec\x8e\xdd\xa3\xeeLh\xd2b\xe1\xc41z\xf0\xa1\xec\xdd8\xdb\xe5\xb3}$\x8b\xa8(tQd[\x92\xf8\x16@\x9ad^\xd3NHHV\xe3\xf3\x12\xc2\x98\xe2\x10\xcb\x89\x0bVs\xef\x12~\x06\xb1\xe64\x93\xbbK\x83z\xb0\xd6d6\xc7\xa4[\xd04f\xf8>F\xbc\xb4_a\xdb\x8c\x1d\x08\xa9\x05\xc4\x9c\x88\xb2i\xd1\x8f\xc8[8\xeb\x0b\x0f\xad\t\xc5{\\\x9d\xb1\xcb\xa7N]~\xcd=n|5k;(l\xb2\xc1\"y\x1e':E\xdbL\xd4\xf3m\xcaV\x9b\x91\x80p\x84\xa2\x8c\x13\xf8\t\xb3F\x83\xf1\xa9\x94LC\x87c\x97_\xf9JKy^\xffz\"\xf1\xf8w\x85\xfc\x90\xfb\xae\xdd\xc5\x0e\xf4#C\xd0\xb3\x98mhq\x1c@b\xc6\x13\x88p[\xa9p[\xad\x18\x0e\x93\xb5\xddw\xb96&|c\x0b\x8b\xfb57\xe3W\xb8%i\xf8|\xbeD\x02\xa1I\x9fbEm\xac\x08N\x14\x11\x9b|\"\x8e\x08Ng<\xc6\xd6\xb5\x88\x18\xa9\x07\xe7E]\xc5v\xe1\xb3b\xda\x10e\xd6a\xc5\x97\x1c\x0b\xf1%\xc3\x1b\t!\xc4\x1f5\x9b2\xdc\xf1\xaa\xd2\x02\xab\xb8\x10\xc9\x86\xfemi\x0c\x04\x03\x81\x86\xee\xe4\xe68,\xb3'\xday9\x18H\xd5\x04\x02\x87\x1e\xe0\xc6\xa2\xeb\xf6\xecF\xcf\xee+\x1f\x027~\x84\xef\xc1\xf6\xb1U/\xa1H\xcc\x95W\x99\x07\xa8@\x82b\xee\xce\x12\xce\x1c\xc2x\xe3\xe0\xbc\xa9\xaf\xa3\xa4#_\xd7W\xdfW\x9b2}$C3\xdc\x02\xa9\xe0N\xd3\xd5n\x85\xc6\x96Af|\n\xe1\xe6\xf9\xfd\xff\x02\xcb\x9e\xdc`\xf8\x82l\x97\xe1\xf1\"\xe8\x15\x05enj\x9a\xa84\xd2\xa3l\x8d\xc1\x1e\xd8\x0b\x7f\x01\x1b4\xff\x00u{R2\xc2*\x89\x86\\\"\xe9\x81\x8d\x82\x1b\xd1\x97J\xeb\xd8\xfa\xd2\xf8\x16\x973\x14\xacm\x8eF\x9c\xaed\xb2\xa9=Y\x03B\x11a\x84\xdfw\x99G\xf0\x06\x8b\xfdN\xccD\xb6\xe3\xc5\xdc>O\xc4\xc6L\xa5\x18\xb42\x0e\xa0H\xfb\xe1\xf1J;p\x10\x13e\xa1;\xd3\x8caX\x89E\x8b9<\x08;\x93\xc3#-\x81 6\x9d\x03\xa9\xbe\xf6\xc4\xa6\x98\x07\xbb\xcaX\xfb\xe5\x80\x99\t\x05\x02\xea\xe1C\x16\xab=\xee\xdd\\\x9f\xa1y/\x87\x0fZbkwC\x16\xd3\x1f\xd2d~6\x8bV-\x8e\xa6(\xc2\xd0tud\xd2\x06n7\xd0\x92c\x91\x99\t-\x8eK\xd9w)Q\x18\xfc\xabM~tQ<\xf9\xee\xed5\x06\xfa\x84\xbe\x87kC\x86\x81]\x9d;Z\xef\x83\xbf\x96\x81\x9f\xe45%V\xa3\xe3\xac(\xe0r+\x0e\x8f'V\xe7E\xa8\nv&\x1d\x05\xcb\xd8\x1c\x92\xe0|\xfb\xdd:v@.\x04\x95\xc2\t\xbf_\xd7\xbdQ\xbc\xc7*uEv\xb9\x0c7B\xf2l[\xed\x8b\x98>l\xc11\x12\x0f8\xfdJ\xc8@cQIv|[\r6\xcc\x9f\x81.\xece,\xd3\x99\xbd\xcb\xf0\xf3F\x92\x9f\x8aF?5\xcf7\xbc\x9f`'\xb9n\xd0($x\x9b\xd0\xca\x85\x19\x8b\x15?l\xfaT\x07\xbe\xfe\x9bpTg\xab\xb0\t\xd5\xe5\x0fy\xc6\x8c\x1b\x1b\x82A\x98\x07\x8f\x1b~\x8b'\x1e\n)\x91H\xcb\xd3\xb8\x99xX\xda\x8fO\xedS\x9f\x9a\x0b\x87\xd1\xbb\x13\x16\xf9\x12\x8f\xa9\xc6\x8b\x11\x89Vm\x10\xb9\r\xfd\x9e5\x03\xc2DF\xd91\x923\xb9n0\xb1\xdds\xf9\xd2\xa5\x1f\x82n\xee\xad\xbe\x8e\xcf\xeat1\xe9r@\xde\x0b/\xb3\x90\xe6\xd9\x80\x19\xae\x1a.\xd1B\xb3\x96\xc5\xe6\xbbI\xc7\xe9A\x83\xab\xa5\xd5}\xf9\xd9\x8fz\xf4s.?\xf5\xa9\xc2\xd2\xbe\x1a\xad\xf1s\r\xa7*/k\raby\xa3\xcd\xbc\xc9(ks\xfb\xfa\x1a,\xd7kK\xa9\xbe\x9e\x9a\xb3\xa7\xc6\xc6\xee}\xf3\xdd\xef\xce(t\xa1\xcd\n\x8f\x06%\x8b1\x15\x92\xb1\x8f\x0e-at\xd5\x96\xc2\xd9\xddwN\x0f\xf5\xd6\x94j\xee\xf6\xe8{\xdf\xfb\xd1wc\x92\x11\x925\x98\xd5b\xcb\xa3\x87YQ\xa6)\xd5\x88\xf15NQ$`Z\xe4qQkL\"l\x1d\x08\x9e9\xf9\xd8\xd3\xb3<\xf8\xfb\xf4\xc0\xdbc\xc1\xb7C\xc0I\xb4\xd1}\xe5\x1b\xe4\x99\xe4\x8f\xff\xd8N\xb8\xfb\xe8\x9e=G\xff\x18\xf9yx\xc9\x18\x7f\x81\xc5\xf8#g\xc2?q\xff\xc5\xbd\xb8\x07\xee\xcf\xa1y\xe6J\xc0Sa\x9e\x0b\xc0~\x85;,HjDCGl7\x11\xed\xe7\xde\x84\xd9\x8dn\xea\xc2?\x8f\xdc\xf1}\xbc\x95\xc5\x1f\xd8y\n\xd7\x93@\x11*\x08\xc7\xd0:41)\x0b1@\xbe\x1a\x041\xe8\xec\t5\xb4>|r\xbfsx\x98\xfb\x7f\xdf&\xaf\xba\xf2\xc7\x95\xceB\xa2\x18\x8f\xf7y\xcf\xd3\xb8\xef9D\xde\x8a\xbfEp\x87},C\xe1Z\xe3\xe7\xbeA\xe6a\x07x\xec\xf6\xd5X\xd9r\xe4\xadE\x7f:\x05g2\x8c=l\x03N\xdfUy\x1b\xb6\x9e\xd6n\xd5\xc1\x9c\xcb[4*\x96\x18\xd6\x9eCVgu~\x10;\x0e\xe0\x90\xa6\x08\xbc\xd1]\xe2T\xb7aITj\xa1\xb2C\x18\xe4v%\xff\xa1\x96\xb1?\x8d\xd7e(in\xcc\xe4\xear\x89X(\xe0\xd21qki\xad\x93\xc7\xbe\x16v\xa3\x0bkIS5ll\xc5\xbc\x84\x89\xbb\x1b\x9b\xc9\xbe\x1c\x82\xeb\x1ew(\x18\x0b\x9b\x92\xd7\x8b-\x8f\xc7\xe5\x8d%QH\xcd`\x8d\xe9\x7fu0\xd81\x91H\xc3R\x07\xd8\x06T\xaa\xc1q\xac\xc3i\xc6\x9ec\xfa\xd3\xb2\xcb\x19\xaca\xab0\xf7\x03\x7f\x0f?\xb0\x95\xbc\xb0\xe8f\x11b\x03\xcb\xa0C\x12\x8c\xcb.\n\x10c]\x1c\xaf*\xcb\xa2@q\x95a\xf5\x84\x9d\r\xed[2\xa2\x8c\xf0\x01\xc7\xbc\xae\xf6\xc0\xa6h\xaa\x86m\xe3jZS\xadA\x93\x9d+3\xbfS\xaf\xfa\xfb\xda\xbc\xf7\xb7\xc2Y\xf5\xb4\x8fm\xb4M\xe6\x15\xc22\x1b\x19\x16t6\xfd\xe1\x90\xd7\x8bS\xe7\xb0\xd7\xabh\x9a'\xf2{f\xc4\xd5}\xd8jG\xa2m\xa9p\xd8\xe5\xc2!D}\x1d6\xa1\x81t\x91i_\x98\xf3\xe7U$\xc7\xd6\xaf\xb6\xd6\xbf\xbf\xf7li\xe2\xdb\x93\x1c\xcd9\xfe\xfe\xf6\xc4\x16e8\x1agn\x80\x9b\x1d\r\x85L\xbf\xdb\x94\xe0\x99*8\x1e\xf6\xf8<^M\xc7\x9ac\xf8\x13A_\\q{B\xa1\x04\xac\xb7\x07\xab\x8e\x0fX2\x8c\xac&+\xc8`Q\xf3#\x80\x1b\x0e$YD\r\x94\xbf\x14\x92m }L\xb2a\x18\x97:\xffb\xc9Z\x81\x15.\t\xd9\x92\x84\x8cQ-#Y\x0cx\x9f\xf5\xc2U\x92\x95\x85d\xaf\xab=&\xd9\xa6F\xe6E5\xf65\xf5\xc1/3\xc1\xaa\x06\xda\xa0/\xc5\xaa\xea\xe6\x88\xad\xfe\xd9\xa6\xe6\xbe\xfe%\xae#\xec\x0b\xf8\x11\xa3F`\xcc\x1f\x08\x80K5\x10\xb6\x9c\x90\xa9\x0e!GY\xb0\x9bm\xc6=^\xc5\xed\n\x85S\xa9\x10\x02f\x08\xae\x1d\xe22\xff\x18\xbf\x8e\xa0:\x9c\x90},\x10\xc0\xd9[\xc0o\xd6\xd4\x05\x83d\x91M\x89\x93z\xb6K\x8dE%!u\xc5A\x15\x0c\xd0\x81\x819\xa4kw\xa8\x89\x04\xce\xe7\xea\x13\xf5\xb5\xa9\x08\x13\xa1\x93\xc4i\xdc\x1a\x9b\xfdfE8;\x1fZ\xaa\xc6\x9bfp\xea\x8d\xdd\xa6\x19\xa9\r\x06\xefC\xfd\xfex\xd2\xf4E\xa8\xc7\x83\x98\xbc!+\xd1h[M8\xe4r\x87\xc2-\x8a^\xeb\xf7\x07}\x89\xa3\xb8N\x80(\x04\x88\x8a\xf2\x15\xed\x8f$\xcb\xbc=\xafGb\x1e\x16\x0b\x82\x9e\xaf\xbaY\x8au\x17@\xe1[)\x07w>\xb2\xf5\xec\xd0*\x11o0qF\x16\xb7\xce\xc5\xfb\x16\xe9h\x7f\xd3\"\x8f\xca\xda\xc7\xafkl4\xcd\x94\xdf0\x9c\x06\xb8\x81v\xc1@\x17\\\xd8\xc1\xc1\xc4\x93\xc3F\x9d\x1f[\x1cO\x085\\#\xb1\xf2\xbb]Q#\xfcd\xb0\xc5\xb8\xf2N2\x07\n\x87\xb08\xdcH\xc6\x8b7\xf4\x81\x91\nUI\x8b!Quw\x83\xa4\xe3\xcc\x00\x8c\xd5X\x80\x91\xcc\xbaP\x83\x00\x1fe\x0e\xb8\xee\x94\xf4Y\xe2\x94e\xe78q:\xe5)\";\xe5]k\xd7\xdcm|\xd7\x8e\xf2\xf0\x9a\xcdk7\x0f\x16z\xbb\x9b\x9aZ\x02n\xb6\x142j-[\xc0l\xa8\xb5\xf9\xbf\xea\xfc\xb9\xc0~/\xd63\xf6;\xaa]}\x17\x86\xcfQ\xd6\xc6B\x08aNQ\x03\x08\xec\xe0\x94\nQ \r>y\x83\xd7\x8b\x10Lc(\xack\xb8\xbb\xe1t(\x1a\xabK\x9a\xba\xcb\xe9Q\xc7\xfdn\xa6\x96\xfc\xf7f\x99Y\xdb\x84\xdf\xa907>\xee\xf1<\r\n\xea3\xbd\xb8\xe9\xe4`\xe1A\xc5\xe5\x8eD\x0c\x1f\x8e&\xbc\xb8:\xc3Net\x8f\xdb\x00\xa35\xdd\xd4\xc1(\xdc\xa8\xf1\x8b\xe6\\\xee)'\x8b\xc0\x83\xf5\xf0F\xe1\x92\xb2\xbf\x8b\x97$\x84\xc7\xb3\xd3l?\xaaB\xc6\x1a\xf3M\xb7q\xc7a_u\xafG\x16\xf6\xa3\x91\x86Pk5F\xa3\x86\x85\x15\x15\x8b\xcfB\xf8\x93\x1dZ\xcb\xd4\x05j\xd8\xbd\x15\xa7\x13wY0\xfc\x84e1\xef\xc6\x0el\xcd\xc6\xc3\x87\x12(\xc4\xad\x14\xdf\x01\x08\xab\x11}<\x91\xfc\x86@\xed\xd9Y-Q1Q$\xd51[\xb5\xf12\x13;\xd9\x07@\xd8I-Qv0\x85w\xc5\xddq\x1e\xb2\xd09E\xfdY\xeb~\xc6\xd5\x07\x14\x8d\xf9\xb6\x91\x96\xe3\x83\xec*\x91\x03w\x11\xf1\x89<0\xf2\xa4\xc8\xc7q\xb1Hg3YC\r\x9f\xb9\xef\xc0_A\xfc\rx\x92c3\xd7\xa1X\x91\r\x87F\x17\x1f\x8b\x1f\xbe\xe6\x18\x97\xad7\r\xd9\x9a\\*\xc7\xba\xf3\x1b\x8b\xd7\x9b\xab\xb7 \x8cDFR\xf0*\x12\xef\x0c\x91\xb9|\x12\xdfQx\xfc\xb8\xbb\xb6a\x02a\xe0E\x14\x0f\xabl\x86\xb0\xa9\x83]\x85\x0b.\xf8\xa3#/h\x0c\x04\xa8\xcf6\x08\x16\xad\xe0\xfe\xf7\xef\x11\x11i/\xb6\xe9h\xcf\xef\xa6\xb28\xf5\xc6D\x9e\xdf\x03\xf0\xc0\x88\xb4D`$4\x1f\x18\xd9\x12I\"\x80qW\xa7\xdb\xb9iO\xfd]\xc3EK~\x8f\xdc!\x8d\xccP\x11\xd9{6zr2\x0f{YA-\x84\xf5\x16\x04\x94\xea\xed\xda\xdasK\xe4\xa3\xe1o\xb1x\x92\xc1\xcf\xe9_\x8d\xbf\x1du\xbf\xd7\xbb`\x01\x14*\x96\x99\x1a\xee\x15\xb1{H*\xe5\xdbj\xee`j\x0e\x89y\x98b}\x89\xb3-\x06\xaa\x99\xf7\x84\xe4b\x84\x95\xdf\xc7z\xe2\x8e\x86\xa0\xcfM\rP\x9f4\xa8\x9b?\x82\x16P\xb3\xe9\xf4U\x19#\xae\xb2;\x19N]r\xb8]^\xbfS\xa71Ea'^\x8a\x12W\x14\xb7\x03\t9~\xd1t\xaa\xfc:\x96\xa6\xc1\x1a?\xf8\\\x84I\x12k\xce\xc9\xb3a\r\xd7\xde0\xd9\xef-\xe6\xe0\xf3\xf8\x8aq\xeculkX\x1d~\x1c\xd4.9\x0b\xabc\xc7\xba,b\xc2H,T.\xff\"\x06\xfd\x06\x8c\xb8A\x88c\xd9\xc9\x9b\xc0\xd45qP\x91\xd0\xf9\xd4\xd5\xb5\xc4\xc54\x9b\xb5\x81\x06>k1\x1ak\xd6\x1aW\xfe\x8ah\xd6\xab\xb1\x8a\xe4\xfeNl(\x1e\x83\xc7_\x17\xcb\xc5sX\xb5\xa34j?\xc5\xbe\xf6\xe8\xff*\x9b\x1a\xb9\x11\x87\xf4\xec\xda\xa0\x19\x88F\xcd\x80\x0b\x9f\x80\x19\xe5W\xe4\x0c\x03\x06\xd0P\xc1d\xd9\xed\x86w\x93\x08\x85\xb0xWS\xee\x88S\xc7\xf9m*\x80O\x8a{8<~\x84s\xcfW\x82\xee\x18\xfe\x9a\xd9\xa3_\x1f\x91\xe0\xdaT\x99^\xc7\xfe\xde)\x99\xf7W\xa08\x84E\x98-\xd5!\x8b\x14/E\xc5I\xf5\x02\x0eJ\xe6\x91\xae\xa3!h\xa0/\x11\xaf\xcf\xc4\xf1w\x1eCm\r~+tb\xbb\x08Q=\xba\x0e\xdb\xaf\\\xa22\x92\xc4\xc8\x03\x08C8\xc1\x0b\xf8\x9c>,\t5[\x10\xa4\x80\xe3\x12\xf6\x1a\xd4\xe3\xbdX\x1fdu\xa1`\xaa\x869\xa7\x10\xda\xde]~_6c\x9a\x08r\xa5|~\xf0\xc1\x0f>\xbc\x88\xf3\xa1\t|\x08\x11\x1b\x1f\xd8:\xbc\x98|\xd0\x8d\x15\xb6\xba\x8b\\\xe0\x83D\xaf\xc6aqW\x86D\x81t\x1d\rY|\xc8\xa4\xe3M\x89&3\xd4\x96\xe5|\xe0#\xbf\xd6\xab\xcbZ^\\U1. 8\xec\x0f\xe1\x9a\x10Fj\xe2\x0e\x02\x8eO\xe2\x89.x\xe8y\xe8\x84\xd7\x93\xc4\x8d\x10\xa6\n\xc9$T\xc1\x05\xff-~y\xb7i6\xac\xf7\x9b\x99\xda@\x80Y\xcb<\x8b$\xf2\xb9\xf7Bk\xdcn\xe6\x06FxT{\x1b\x1b\xa1(\"\xd5\"\x1b\xc2\xf8\xb8\x98\xa9\xdcW\x82\x93dm\xb8g\xd9Y\xfe~\x88{~\xa6F yQ\xc7S\xa8\xe5Su\xf979W\xac\xd8\xb9\xc7\xc5|A\x87\xb5\xcd\xd3\xec\xb7f\x98\xcdf\xe7\xef\x0fH\x06<\x94-\x0f\x0e\\\xe9`\x87H\xc9\x1a\x8a\xbbP\xaf\x0e\x86\xb0#\xc3\x9a\xa1\xb2\x89\x12\x9a\xb8X\xebw9\xc5\xde\x84K~-\xdb\x9b\xd4\xd7\xfd\xfd\xd8Z{.]\x83\xa5m-]\xbb(\xb6\x16\xb6\xdd\xfa\xb2\xa4\xb5\xecYJU\xa5o\xcc\xa5|\x12#U\xc2Y\xa7\x1f[\x11\xa73^\xc4\xb62\xea\xf7{\xfd|\xe3\x02\xbb\xea\xf2\xbb\xf1+\x99\xf1\xe2V\xa9\x92\x8c+V\xc8L\xd6\x99\xa7\xe4\x859\xd5\x82\xf5\x98\xe6\x18T@\xe6\xe3\xc3&\x86]\x1b\xc6^\x07V\"\x18\xf5\xf9\xf8m\xb7\xbf\xc2\x13\xff*|\xdb\x9ebg\x16\x86\x1a\x810\xc3+I[d\x16\xd5d\xe7\x95\xecj\x16q\x8c\xb3c\x90)\x82\xf4\xae&3nF\xea\xf8\x01H\xd5\xedc\xeem\xa1`\xed\x195(\xe0\xa2\x83\xa1\x17\xc7\xd2\xd8\x17S\xa5\xa9YN1\n\x95\xc152\xc5m\x177\x0c\xbb?\x08\x07O\xf3\rF\xda\x1d Ov\xd4G\xd6\xf8\x94\xb4\x1bGA\x9c\xffQ\xce\xff\x8b$\xcd\xbe\xef\x90\xc4*\x1de\x91\xa9\xe5\xe3t\xec\xfc\x04\xeb{\x9a\xa6\xab[C\xdc\x9c_\x1c\xa2c\xb2\xc8\"\x98\xccv:\xbb\x93\xd8\xc6'\xe0 \x05\xbdF\x82Jq\x99\xb23\x94P\xa8y\xff\xfe4\xe6\x8b\xaf\xe6\x1e\x8f[\xb4\x83\x11\xb1\xb2\x97\x83\x1a\x17\xa9-\xd6h\xd6-'I\x02\xbc\x8dEd\xf8\x1f]v\x99A\x85\x1d.\xf2\xbb\xbf\xbdQ\x8c\xfe\xe5j\xb05\\N\xf6\xd5\x98\x8e\x8b\xe9\xfc\xe4\xc5\xdb64eD\x14\xefv\xb4e\xb2\x1b%N\x8a\xc6\xc1\x006Y\xdc\x94l\xa9\x9e\x9bP\x11\xd0\x8b\x07\x16\x05\xf4\x06\xf8HT+\xaa\x17\xadI\xf9\x1b\xdc\xb8\x9c\xe86\x13\xb5\xe9\xd8\xc5G\xdc\xe7\xdch$b\xaa7\xec=~\x9c\xdd\xde\xe5\xf3\xf6\xe2?\x15\xdd\xbb\xcb\x9aT>\x97,l\xa8\xed\xcc\xd7\xde\xb0w\xc3\x86=\xfbJ%\xfew\xa2\xe1\xff\xbd\x18mf\x98\xbe$c\x1e\xb4\x00\x9aA\xb9\xc2g\xfbm\x0b\xb3\xe2\x00C\xdf\xcd\xff\xe0s&\xd4\xda\xc2O\xcc\xd9m\ra\xaf\x0b\x85E\xb7\xf78\xb3\x98\xb2\xe0z\x8b\x9e\x83 \x821\x9f\x87\xb5'9p\xd4\x8b\x0b\xd9\x1bk\xfa#p\xd5\xa5\x8b8\xfc\x88\xdf\x1cs\xbb}\xec\xb0\x8b\x05\x8fq?\xe0\x15\x0f\x1fIx\r\xdf\xfc\x89\xe1\xc5\x7fG\xecp\xf6\xc0C\x0fO\xf2\xd8\xe1\x93\x02\xb7\xc4\x02\xb7\x8a\xd8a\xe8\xca\xfb\xc8\xd3\xc8OI\x13\xbb\xd9\x92B!?\x99\x02%\xfc<\x83\xcd\x97\xd9E\xf3E\x85A\xb7\x0e\xcc\xe3\xd1H\xc8\xe7u\xbbH\x13mZ8W-\x14x\xc4\xbf\xdfR\xd0\xbe^t\\\x8f\r96Y\xecl\x03\xd9\x0b\xd8\xc2\xc3m\xc2W.LMC\xaa\x1c\xab\xad\xcfd\xa8\xcb\x1d\x0f\xc2\xc6`\xdf\xd0\x18s:\xc3NW(9\x1cnI\xb4\x1a\xae\xceL\xdc\xe9\xe21\xca]W>\x88\xbfP\xfa+Pg\x16\x8d\xf9o\x99T/C\x9b\xd9]\xf1\xf8\xaf\xee\xf8<Y<&\xeb4C\xe1F\x8eq\x8d\x99Z\xb8\xa7lll8\xe3\x04\x00c\xc2)(.;\x01\xbd\xb1>\\\xd7V\xc7\xee\x80F\xad!4\xf7a\xffW\xe8\xe3#\xaa\x0e\x81\x9b\xb6h\x84\x8b=\x14L\xb8\xdc4\x83?\x16X\x1b\x1d\xc1\x1d\x0ckP\x12\xc5\xf0\x025k\xc3.g<\xd3\xe92Z\x13-\xe1\xe1d\xc8\x85\x819c\x8d\t8.\x0e~\xc7{\x1a~\xd4#q\x1f\xb9P\xecK\xa7\xa0\x1c^\x0f;\x11\\\xa0\xf5\xda`Q\x02Wdq\xceVG\xeb\xf8\xcaP\xbfhY\xa8\xde!\xb2\xddN\xb8\xd5\xc9\xben\x85/S\xb0\xfdD\x10\x9bP\xbc\xcd\xd3*\xb6\x0f \xd5\xe5\x9c\x86\x99\xc2\x9dX\xec)\x9d8E\x92XFF\xc6\x85\x03a\x88\x1a\x1f|\xebl;\xbfe\xe5&>\xe8\xe3h\xb1d8\xbd\x9a\xc7\xe1\xc6\x1e\x95\x85\x07tU\x91\xb0\xba\x07\xe8v\xc4\x16=\xba\xae \x83\xbbs8\xfdE\x1c\xca\x87\xafa\xb8u\x98FES\x10\x94\xe3_K\xf3i\xd1\\\xb7\xd9{\xcd\xcfD\x1a\x9f\t\xfc\x93\xb6\xff\xf5\xd2\xd5\xcf\x7f\x99\x16P\xb1jh\x99\x10\xb4\xa4W\x01-\\D\xab\x86/\xa0c\xd5\xf0eb\x15\xd1\xc2\x19\xb3jd\x04ZV\t_&V\x11- e\x95\xd0\x02*89\xabA_@\xc6\xaa\xa1eB\xd0\xb2\x1ad\xc4\tY5|\x01!\xab\x86/\x13\xab\x88\x16.\xa5U##\xd0\xb2J\xf82\xb1\x8ah\x01%\xab\x84\x96\t.\xa4\xd5\xe1K\x81%\xab\x86\x96\tN\xcb*\xf1\xa5\x98qY5|\x01\x1d\xab\x86/\x13\xff -8[\xe3\xbd\xb3}\xfbb\xa2\xce^/%\xea\xb2\x12\x9aX-\xbb#K@\xab\xc6\xab\x9b\xf8\xc7$\xf4\x9f\xa3\x85M\xa0\xd52\x8b,\xb5]\x1d\xbb#\xd0\xb1\xaa\xf4e\xb5\xac\x00\x96\x80V\x87W\xc7$\xb4Zd\xc4\xc8X-|a\x94\xac\xa6y\xb4jl\x1dX\xb2jv\x8d\x13\x13\xabJw'V\t-l\x07\xb0j<\xcc\xf4\xc4\xaa\xb2\xbb\xcb\xca\xc8\xfa?K\xe5\x17\x80\x96&r_~\xd5{\x92\xfd\x9fLK\x94O-S~`\x99\xf2\xe9e\xca\x0f.S>\xb3L\xf9\xa1e\xca\x0f/S~d\x99\xf2\xd9e\xca\x8f.S~\xcfe\xca\xef\xb5L\xf9\xf1e\xcaO,S~r\x99\xf2{/S~j\x99\xf2\xd3\xcb\x94\x9fY\xa6\xfc\xa6e\xca\xcf.S~\xf32\xe5\xe7\x96)\xbf\xcf5\xe5\xb7Zz\xb5L\xf9\xd42\xe5\x07\x96)\x9f\xbe\xb6\xdc\xaeWw\xbcM\x94\x9fGy\xb3\xd5/\xfbj9}\xc8\x1d\xef\"\xce9\x97\xf4\xc6;\xdeU\xe9\xcfq\xdc+c6\xdc)\x81\xab,\x85{\xc7\xfbl\xb8\x07\x04\xaecI\xdc\x8a\rwZ\xe0\xaaU\\\xb9\x8a{-\xbd\x07\x05\xaeV\xc5u,\x8f;#p\xf5\xf9v\x97\x1f\xdb!\x81\xeb\xac\xe2\xd2\xc5\xed\xdeb\xc3=,p]\xd7\x81{D\xe0\xba\x97\xc2\xb5\xec\x9c\xa4\x92\x87\x0b\xd9\\\xb6\xbd{T\xbc\xebY\xb2\x9f\x87\xd8p\xef)p\xbdK\xe1^i\xe5\xfd4\x91\x07r\x1c\x83<\x91\xe38l\xed\xbdM\xe0<\x98\xe3\xf8\x96\xc4\x99\xb3\xf5y\\\xf4\xe9\xaf\xf6\xb9d{\x8f\xe48f\xb5=\x9bl\xdf%pn\xe18\x81\xf9>\x97\xc2\xb9\xc0q\x82+\xd2\xfe\x08\x8e\x13Z\xb1\x9d\x07p\x9cp\x15GZ\xaa\x9d\xfbs\x9c\xc8\x8a}\xdd\xc6q\xa2\xf3\xed,\xd5\xd7C9Nl\xc5v\xee\xc7q\xe2\xf3\xfcY\n\xe7A\x1c'1\xdf\xd7\xf2:\x7f\x1f!\x93\xe4\xfc\xbc[Jgn\xb5\xcd\x8f\x9a%q?]\xc5\xb5\xcd\x8f\xd4\x92\xfa\x15\xac\xe2\xda\xe6G\xfa:\xda\xad\xce\x8f\xda\xa5u\xc8\x86;+p3\xf3\xed.\x8f{\x93\xc0\xad\xab\xe2.)\x9fI\x8eS\xbf\xa2\x0c\xa78NvE\xf9\x1c\xe08\rK\xca\xf9\x9d\x02g\x9a\xe34\xae\xd8\xd7A\x8e\xd3\xb4\xa2\xfe\xcep\x9c\xe6\x15u\xea\x10\xc7iY\xb1\x9d\xc3\x1c\xa7uE\x9c#\x1c\xa7m\xc5\xbef9Nn\xc5\xb1\x1f\xe58\xf9\x15\xfb\xba'\xc7i_\x11\xe7\x18\xc7\xe9X\x11\xe7^\x1c\xa7sE\x9a\x8fs\x9c\xae\x15eq\x82\xe3t/\x89sA\xe0\x9c\xe48=+\xb6so\x8e\xd3\xbb\xa2\xbd9\xc5q\xfaV\x1c\xd7i\x8e\xd3\xbf\xe2\xb8\xcep\x9c\x81\x15eq\x13\xc7)\xac\xd8\xd7Y\x8e3\xb8\"\xce\xcd\x1cghE\x9cs\x1cg\xcd\x8a8\xf7\xe18k\x97\xc4y^uN\xdb\xd6\xc3uK\xda\x8a\xb9*\xaem=\xbcS\x15w\x85v\x8f\t\xdc\xf5K\xda\xb6a\x1b\xee\xbd\x04\xee\x86%\xdb}a\x15\xd7\xb6>\x16\x97l\xf7\x016\xdc\xb3\x02wxE;\xf8\x10\x9b\xcfVZ\xd1\x0e>\xc4\xe6\xb3\x95\xaf\x03\xb7\xea\xb3\x8d\\\x07\rU\x9fm\xf4:\xda\xad\xfal\x1b\x97\xb6\xc5U\\\xdb\x9a\xb4iI\x1an\xad\xe2\xda\xd6\xa4;\xcf\xfbw\xcb\xb5\xbb\xb0&m\x9eow9\xdc\x855i\xcb\x92\xf4\xdeR\xc5\xb5\xadI[\x97\xc4}g\x15\xd7\xa6\xbf\xdb\xae\x83\x86\xaa\xfe\xde\xe5:p\xab\xfa\xbb\xfd:p\xab\xfa\xbbcI\xdc\xb7Wqm\xfa\xbbsY_b\x01\xf7\x84\xc0\xddu\x1d\xb8'\x05\xee\xee\xeb\xd0\x87{\x0b\xdc=\xd7\xa1\x93\xa7\x04\xee\xde\xeb\x18\xdbi\x81{\xd7\xebh\xf7\x8c\xc0\xbd\xe1:\xf8[\xf5;\xf6]\x07nu\xce\x8f]\x07\xee\xcd\x02w|\x1ewy\x9d<'p'\xae\xa3\xdd\xaa\xbfx\xb7%q\xcfWm\x94M\xc6\x7fk\xbc\x8cM\x00\x00B\x18\xe80?\xd6\xab\xe3\x88[\x0bB\x8a@\n\xfb#\xcdA\xe0\xbed\x1b,9\xf6\xc3.\x1c\x87\xfc\xc9\x07\x96\x1c\xa7b\xb9y\xd71wV\x99\rPK\x01\x02?\x00\x14\x00\x00\x00\x08\x00\x00\x00\xffJX\xad\x84\xf5\x17\x10\x00\x00\xec9\x00\x00\x08\x00$\x00\x00\x00\x00\x00\x00\x00 \x00\x00\x00\x00\x00\x00\x00font.ttf\n\x00 \x00\x00\x00\x00\x00\x01\x00\x18\x00\x00\xd88\xa0\xca\t\xd3\x01B\x85X\x10\xe9\xe0\xd8\x01\x88\x11\x96\x0c\xe9\xe0\xd8\x01PK\x01\x02?\x00\x14\x00\x00\x00\x08\x00a~OU+8F\x0c\xf16\x00\x00\x18\x89\x00\x00\x0c\x00$\x00\x00\x00\x00\x00\x00\x00 \x00\x00\x00=\x10\x00\x00font_ext.ttf\n\x00 \x00\x00\x00\x00\x00\x01\x00\x18\x00_\xc6P\x99\xe8\xe0\xd8\x01B\x85X\x10\xe9\xe0\xd8\x01\x00\x98\xe5\x1aK\x1a\xd3\x01PK\x05\x06\x00\x00\x00\x00\x02\x00\x02\x00\xb8\x00\x00\x00XG\x00\x00\x00\x00"


def get_code_39_font_data():
    """Returns a BytesIO file object containing the loaded normal Code 39 font. Takes no arguments."""
    with zipfile.ZipFile(io.BytesIO(FONT_DATA), "r") as z:
        with z.open("font.ttf", "r") as f:
            return io.BytesIO(f.read())


def get_code_39_extended_font_data():
    """Returns a BytesIO file object containing the loaded extended Code 39 font. Takes no arguments."""
    with zipfile.ZipFile(io.BytesIO(FONT_DATA), "r") as z:
        with z.open("font_ext.ttf", "r") as f:
            return io.BytesIO(f.read())


def get_code_39_font_and_extended_font_data():
    """Returns a tuple of BytesIO file objects containing the normal and extended fonts. Takes no arguments."""
    with zipfile.ZipFile(io.BytesIO(FONT_DATA), "r") as z:
        with z.open("font.ttf", "r") as f:
            normal = io.BytesIO(f.read())
        with z.open("font_ext.ttf", "r") as f:
            extended = io.BytesIO(f.read())
    return normal, extended


def encode_39(val: str):
    """Makes a string ready for the Code 39 font, returns a String."""
    return f'*{val.replace(" ", "_")}*'


class Encoder:
    """Encoder object to set overridable defaults and hold loaded font data. Setting a value in a method will temporarily overide the default."""

    def __init__(
        self,
        default_size: int = DEFAULT_SIZE,
        default_padx: int = DEFAULT_PAD,
        default_pady: int = DEFAULT_PAD,
        default_background: tuple = BACKGROUND,
        default_foreground: tuple = FOREGROUND,
    ):
        self.size, self.padx, self.pady = default_size, default_padx, default_pady
        self.background, self.foreground = default_background, default_foreground
        self.font = get_code_39_font_data()
        self.ext_font = get_code_39_extended_font_data()

    def make_barcode(
        self,
        val: str,
        size: int = None,
        padx: int = None,
        pady: int = None,
        background: tuple = None,
        foreground: tuple = None,
    ):
        """Make normal barcode, returns a PIL Image object."""
        self.font.seek(0)
        return self._make_barcode(
            val, self.font, size, padx, pady, background, foreground
        )

    def make_extended_barcode(
        self,
        val: str,
        size: int = None,
        padx: int = None,
        pady: int = None,
        background: tuple = None,
        foreground: tuple = None,
    ):
        """Make extended barcode, returns a PIL Image object."""
        self.ext_font.seek(0)
        return self._make_barcode(
            val, self.ext_font, size, padx, pady, background, foreground
        )

    def _make_barcode(
        self,
        val: str,
        font: io.BytesIO,
        size: int = None,
        padx: int = None,
        pady: int = None,
        background: tuple = None,
        foreground: tuple = None,
    ):
        """Core encoder barcode method, returns a PIL Image object."""
        return make_barcode(
            val,
            font,
            size or self.size,
            padx or self.padx,
            pady or self.pady,
            background or self.background,
            foreground or self.foreground,
        )


def make_barcode(
    val: str,
    font: io.BytesIO,
    size: int = DEFAULT_SIZE,
    padx: int = DEFAULT_PAD,
    pady: int = DEFAULT_PAD,
    background: tuple = BACKGROUND,
    foreground: tuple = FOREGROUND,
):
    """Core barcode generation function, returns a PIL Image object."""
    val = encode_39(val)
    loadedfont = ImageFont.truetype(font, size)
    l, t, r, b = loadedfont.getbbox(val)
    img = Image.new("RGBA", (r - l + 2 * padx, b - t + 2 * pady), tuple(background))
    ImageDraw.Draw(img).text(
        (padx, pady),
        val,
        fill=tuple(foreground),
        font=loadedfont,
        # anchor="lt",
    )
    return img


if __name__ == "__main__":
    import os, argparse

    print(__doc__)
    parser = argparse.ArgumentParser()
    parser.add_argument(
        "value",
        help="Value or text file with one entry per line to encode. Set -f flag for file mode.",
        type=str,
    )
    parser.add_argument(
        "-e",
        "--extended",
        action="store_true",
        help="Set flag to use extended font. Extended font has a text label below it.",
    )
    parser.add_argument(
        "-f",
        "--file",
        action="store_true",
        help="Set flag to load from text file at path specified by value.",
    )
    parser.add_argument(
        "-sc",
        "--skip_check",
        action="store_true",
        help="Set flag to skip check to see if barcode file already exists",
    )
    parser.add_argument(
        "-i",
        "--ignore_duplicates",
        help="Set flag to ignore error normally raised on duplicate barcode names being found in the barcode file. File Mode only.",
        action="store_true",
    )
    parser.add_argument(
        "-m",
        "--manifest",
        help="Set flag to generate / update barcode manifest json.",
        action="store_true",
    )
    parser.add_argument(
        "-o",
        "--output",
        help='Set to specify output directory name. Defaults to "output"',
        type=str,
        default="output",
    )
    parser.add_argument(
        "-t",
        "--type",
        help=f"Set to specify output file type (without filetype) / directory name. Defaults to {DEFAULT_TYPE}",
        type=str,
        default=DEFAULT_TYPE,
    )
    parser.add_argument(
        "-s",
        "--size",
        help=f"Set to specify barcode font size. Defaults to {DEFAULT_SIZE}",
        type=int,
        default=DEFAULT_SIZE,
    )
    parser.add_argument(
        "-px",
        "--padx",
        help=f"Set to specify barcode x-padding. Defauts to {DEFAULT_PAD}",
        type=int,
        default=DEFAULT_PAD,
    )
    parser.add_argument(
        "-py",
        "--pady",
        help=f"Set to specify barcode y-padding. Defauts to {DEFAULT_PAD}",
        type=int,
        default=DEFAULT_PAD,
    )
    parser.add_argument(
        "-fg",
        "--foreground",
        help=f'Set to specify barcode foreground in RGBA hexadecimal. Defaults to "{DEFAULT_CL_FG}"',
        type=str,
        default=DEFAULT_CL_FG,
    )
    parser.add_argument(
        "-bg",
        "--background",
        help=f'Set to specify barcode background in RGBA hexadecimal. Defaults to "{DEFAULT_CL_BG}"',
        type=str,
        default=DEFAULT_CL_BG,
    )
    parser.add_argument(
        "-mn",
        "--manifest_name",
        help="Set to override default manifest name.",
        type=str,
        default="manifest",
    )
    parser.add_argument(
        "-om",
        "--overwrite_manifest",
        help="Set to overwrite an existing barcode manifest json (losing current entries), by default an existing json will be updated to include new entries.",
        action="store_true",
    )
    args = parser.parse_args()

    def hex_to_rgba(val: str):
        """Tries to convert rgba hex to rgba, on failure converts rgb hex to rgb and sets full opacity"""
        try:  # Hexadecimal RGBA
            return [int(val[i : i + 2], 16) for i in range(1, 8, 2)]
        except ValueError as e:
            # If hexadecimal RGBA failed try hexadecimal RGB at full transparency
            rgba = [int(val[i : i + 2], 16) for i in range(1, 6, 2)]
            rgba.append(255)
            return rgba

    # Instantiate encoder
    encoder = Encoder(
        default_size=args.size,
        default_padx=args.padx,
        default_pady=args.pady,
        default_background=hex_to_rgba(args.background),
        default_foreground=hex_to_rgba(args.foreground),
    )
    # Make output dir
    if not os.path.exists(args.output):
        os.makedirs(args.output)
    elif os.path.isfile(args.output):
        raise FileExistsError(
            print(f"Found file at supplied output - {args.output}, not directory.")
        )

    if args.file:
        print("File Mode.")
        if not os.path.exists(args.value):
            raise FileNotFoundError(f"Could not find value list at {args.value}.")
        elif not os.path.isfile(args.value):
            raise FileNotFoundError(f"{args.value} is not a file.")
        try:
            with open(args.value, "r") as f:
                values = f.readlines()
        except Exception as e:
            raise ValueError(f'Failed to load values file - "{e}"')
        if not values:
            raise ValueError("Values file is empty.")
        print("Processing batch...")
        seen = []  # dict to warn about duplicates
        for v in values:
            # Skip blank lines and lines that start with comment tags
            v = v.strip()
            if not v or v.startswith("#"):
                continue
            if "#" in v:  # Remove midline-comment
                v = v.lsplit("#", 1)[0].strip()
            if v in seen:
                if args.ignore_duplicates:
                    print(f"Ignoring duplicate {v}")
                else:
                    raise ValueError(f"Duplicate {v}")
            seen.append(v)
        # Check if output files already exists
        if not args.skip_check:
            for v in seen:
                f = f"{args.output}/{v}.{args.type.lstrip('.')}"
                if os.path.isfile(f):
                    raise FileExistsError(f"Barcode file for {v}, {f} already exists.")
        barcodes = {}
        print("Generating barcodes...")
        for v in seen:
            print(f"Generating barcode for {v}")
            f = f"{args.output}/{v}.{args.type.lstrip('.')}"
            encoder.make_barcode(v).save(f)
            barcodes.update(v, f)

    else:
        print("Single Mode.")
        f = f"{args.output}/{args.value}.{args.type.lstrip('.')}"
        if not args.skip_check:
            if os.path.exists(f):
                raise FileExistsError(f"File for {args.value} already exists - {f}")
        print(f"Generating barcode for {args.value}")
        barcode = encoder.make_barcode(args.value).save(f)
        barcodes = {args.value: f}

    print(f"Generated barcode(s): {json.dumps(barcodes, indent=4)}\n")

    if args.manifest:
        manifest = f"{args.output}/{args.manifest_name.rstrip('.json')}.json"

        def write_manifest(data: dict):
            with open(manifest, "w+") as f:
                json.dump(data, f)

        if os.path.isfile(manifest):
            if args.overwrite_manifest:
                print(f"Overwriting manifest at {manifest}")
                write_manifest(barcodes)
            else:
                print(f"Updating manifest at {manifest}")
                with open(manifest, "r") as f:
                    m = json.load(f)
                m.update(barcodes)
                write_manifest(m)
        else:
            print(f"Creating manifest at {manifest}")
            write_manifest(barcodes)
